<?php
/**
 * Import / auto-find module
 * http://www.aa-team.com
 * ======================
 *
 * @package		WooZone Contextual
 * @author		Andrei Dinca, AA-Team
 * @version		1.0
 */
!defined('ABSPATH') and exit;
if (class_exists('WooZonePNF_auto_find') != true) {
    class WooZonePNF_auto_find
    {
        
        const VERSION = '1.0';
        
        /**
         * helpers storage
         *
         * @var array
         */
        public $parent = array();
        public $config = array();
		public $wpdb = null;
        public $search_in_post_meta = array();
        
        /**
         * The constructor
         */
        public function __construct($parent = array())
        {
        	global $wpdb;
			$this->wpdb = $wpdb;
			
            // load parent
            $this->parent = $parent;
			
			$this->config['db_name'] = $this->wpdb->prefix . 'zonecontextual';
            
            // AJAX request - save hits on frontend
            add_action('wp_ajax_WooZonePNF_save_hits', array(
                $this,
                '_ajax_save_hits'
            ));
            add_action('wp_ajax_nopriv_WooZonePNF_save_hits', array(
                $this,
                '_ajax_save_hits'
            ));

            // create AJAX request
			add_action('wp_ajax_WooZonePNF_auto_find_list_table', array(
                $this,
                '_ajax_fetch_list_table'
            ));
			
			add_action('wp_ajax_WooZonePNF_launch_search_for_context', array(
                $this,
                '_ajax_fetch_search_for_context'
            ));
			
			add_action('wp_ajax_nopriv_WooZonePNF_launch_search_for_context', array(
                $this,
                '_ajax_fetch_search_for_context'
            ));
			
			add_action('wp_ajax_WooZonePNF_import_keywords', array(
                $this,
                'import_keywords'
            ));

			add_action( "toplevel_page_WooZonePNF", array( $this, 'extra_head' ) );
			require_once $this->parent->path( 'AUTO_FIND_DIR', 'list-table.class.php' );
        }
		
		public function extra_head()
		{
			if( "auto-find" == WooZonePNF_action() ){
				wp_enqueue_script( 'WooZonePNF-auto-find', WooZonePNF()->includeUrl( 'auto-find/app.class.js' ), array(), self::VERSION );
				wp_enqueue_style( 'WooZonePNF-auto-find', WooZonePNF()->includeUrl( 'auto-find/styles.css' ), array(), self::VERSION );
			}
		}
		
		private function current_sub_action()
		{
			return isset($_REQUEST['sub_action']) ? $_REQUEST['sub_action'] : '';
		}
        
        public function print_interface()
        {
			return $this->list_items();
			
           	wp_die("invalid action!");
        }
		
		public function list_items( $pms=array() )
		{
            // pms: action_status
            extract($pms);

			// Create an instance of our package class...
			$list_table = new WooZonePNF_auto_find_List_Table();
			
            // Fetch, prepare, sort, and filter our data...
            $list_table->prepare_items();
            
            $stat_msg = '<span class="WooZonePNF-action-status WooZonePNF-message" style="display: none;"></span>';
            if ( isset($action_status) && !empty($action_status)
                && is_array($action_status) && isset($action_status['status'], $action_status['text']) ) {
                
                switch ($action_status['status']) {
                    case 'invalid':
                        $stat_msg = '<span class="WooZonePNF-action-status WooZonePNF-message WooZonePNF-error">' . $action_status['text'] . '</span>';                        
                        break;
                        
                    case 'valid':
                        $stat_msg = '<span class="WooZonePNF-action-status WooZonePNF-message WooZonePNF-success">' . $action_status['text'] . '</span>';
                        break; 
                }
            }
			
			ob_start();
			?>
			<div class="wrap">
			    <?php echo $stat_msg; ?>

				<form id="WooZonePNF-auto-find-list-table" method="get">
					<input type="hidden" name="page" value="<?php echo $_REQUEST['page'] ?>" />
					<?php $list_table->display() ?>
				</form>
				
			</div>
			<?php
            $html = ob_get_contents();
			ob_clean();
            return $html;
		}
		
		public function auto_fill_manage_container( $item_id=0 )
		{ 
			$html = array();
			$has_keywords = false;
			$auto_find_products = get_post_meta( $item_id, '_WooZonePNF_auto_detect_amz_products', true );
			
			$html[] = '<div class="WooZonePNF-auto-find-row-box" id="auto-find-post_id-' . ( $item_id ) . '">';
			if( count($auto_find_products) > 0 && is_array($auto_find_products) ){
				$style_width = "style='width: " . ( 410 * count($auto_find_products) ) . "px'";
				$keywords = WooZonePNF()->keywords->get_keywords_by_ids( $auto_find_products );
				if( count($keywords) > 0 && is_array($keywords) ){
					$html[] = '<ul class="WooZonePNF-keyword-attached" ' . ( $style_width ) . '>';
					$cc = 0;
					foreach ($keywords as $keyword) {
						$has_keywords = true;
						$html[] = '<li>';
						$html[] = 	'<span class="WooZonePNF-keyword-attached-nr"><span>#' . ( ++$cc ) . '</span></span>';
						$html[] = 	'<a class="WooZonePNF-keyword-attached-image" href="' . ( $keyword['product_SmallImage'] ) . '" target="_blank"><img src="' . ( $keyword['product_SmallImage'] ) . '" /></a>';
						//$html[] = 	'<div class="WooZonePNF-keyword-attached-phrase">Keywoard: <span>' . ( $keyword['keyword'] ) . '</span></div>';
						$html[] = 	'<div class="WooZonePNF-keyword-attached-phrase"><span>' . ( $keyword['keyword'] ) . '</span></div>';
						$html[] = 	'<div class="WooZonePNF-keyword-attached-title">' . ( $keyword['product_Title'] ) . '</div>';
						$html[] = 	'<div class="WooZonePNF-keyword-attached-brand">by: <span>' . ( $keyword['product_Brand'] ) . '</span></div>';
						$html[] = 	'<div class="WooZonePNF-keyword-attached-prices"><del>' . ( $keyword['product_ListPrice'] ) . '</del><span>' . ( $keyword['product_ListPrice'] ) . '</span></div>';
						$html[] = 	'<div class="WooZonePNF-keyword-attached-actions">';
						$html[] = 		'<a href="#remove" class="WooZonePNF-button WooZonePNF-small red WooZonePNF-keyword-remove" data-keywoardid="' . ( $keyword['id'] ) . '">Remove</a>';
						$html[] = 		'<a href="' . ( admin_url( 'admin.php?page=WooZonePNF&sub_action=modify&id=' . $keyword['id'] ) ) . '" class="WooZonePNF-button WooZonePNF-small blue WooZonePNF-keyword-modify">Edit</a>';
						$html[] = 	'</div>';
						$html[] = '</li>';
					}
					$html[] = '</ul>';
				}
			}
			$html[] = 	'<div style="' . ( $has_keywords === true ? 'display: none;' : '' ) . '" class="WooZonePNF-message WooZonePNF-info WooZonePNF-message-small">You never search to auto find contextual products for this page. <a href="#" class="WooZonePNF-button WooZonePNF-small green WooZonePNF-search-for-context" data-postid="' . ( $item_id ) . '">Launch search now?</a></div>';
			$html[] = '</div>';
			return implode( "\n", $html );
		}
		
		private function get_body( $post_id=0, $strip_tags=false, $remove_links=true )
		{
			
			$post_content = array();
			$post = get_post( $post_id, OBJECT);
			
	       	$post_content[] = apply_filters( 'autop', $post->post_content );
			$ret_html = implode( "\n", $post_content );
			if( $strip_tags == 1 ){
				
				// remove all links
				preg_match_all('/<a .*?<\/a>/i', $ret_html, $a_matches ); 
				if( count($a_matches) > 0 & isset($a_matches[0]) ){
					foreach ($a_matches[0] as $html_elm) {
						
						$ret_html = str_replace( 
							$html_elm, 
							md5($html_elm), 
							$ret_html 
						);
					}
				}
				
				$ret_html = strip_tags( $ret_html );
			}
			
			return $ret_html;
		}
		
        public function choose_from_founds( $founds=array(), $post_id=0 )
		{
			// debug not found html
			//$founds = array();
			
			$status = 'valid';
			
			$html = array();
			$html[] = '<div class="WooZonePNF-autofind-loader">';
			$html[] = 	'<div class="WooZonePNF-autofind-lightbox-container">';
			$html[] = 		'<h1 class="WooZonePNF-autofind-lightbox-title">';
			$html[] = 			'Auto find keywords status';
			$html[] = 			'<a class="WooZonePNF-icon-close" href="#"><i class="fa fa-times"></i></a>';
			$html[] = 		'</h1>';
			
			$found_products = 0;
			if(count($founds) > 0 ){
				foreach ($founds as $found) {
					$found_products = $found_products + count( $found['results'] ); 
				}
			}
			
			// html if not founds any keywords
			if( $found_products == 0 ){
				$status = 'not-found';
				$html[] = 		'<span class="WooZonePNF-icon-no-ideea"></span>';
				$html[] = 	'<div class="WooZonePNF-message WooZonePNF-error">';
				$html[] = 		'Sometimes for the non-usual text, the Amazon API fails to return any relevant products at the first try.<br />';
				$html[] = 		'Do you want to <a href="#" class="WooZonePNF-button WooZonePNF-small green WooZonePNF-search-for-context" data-postid="' . ( $post_id ) . '">Try again</a>?<br />';
				$html[] = 		'We recommend that you try to search again or use the "keywords" module where you can manually add keyword entries for this post.<br />';
				$html[] = 		'Do you want to <a href="' . ( admin_url('admin.php?page=WooZonePNF&WooZonePNF_action=keywords') ) . '" class="WooZonePNF-button WooZonePNF-small green WooZonePNF-search-for-context">Add manual keywords</a>?';
				$html[] = 	'</div>';
			}

			else {
				
				$status = 'result-found';
				
				$html[] = 	'<div class="WooZonePNF-products-found" data-post_id="' . ( $post_id ) . '">';
				$row = 0;
				$selected_nb = 0;
				foreach ($founds as $found) {
					$html[] = 	"<table class='WooZonePNF-product-found-item' data-item='" . ( stripslashes( json_encode( $found['product'] ) ) ) . "'>";
					$html[] = 		'<tr>';
					$html[] = 			'<td class="WooZonePNF-product-found-img">';
					$html[] = 				'<a href="' . ( $found['product']['DetailPageURL'] ) . '" target="_blank">';
					$html[] = 					'<img src="' . ( isset($found['product']['SmallImage']) ? $found['product']['SmallImage'] : '' ) . '">';
					$html[] = 				'</a>';
					$html[] = 				'<span>' . ( $found['product']['ASIN'] ) . '</span>';
					$html[] = 			'</td>';
					$html[] = 			'<td class="WooZonePNF-product-found-keywords">';
					
					$html[] = 			'<span class="WooZonePNF-product-found-title">' . ( $found['product']['Title'] ) . '</span>';
                    
					if( count($found['results']) > 0 ){
						//$cc = 0;
						//$selected_nb++;
                        $min_depth = 2;
                        
						foreach ($found['results'] as $result) {

                            $words_count = WooZonePNF()->keywords->keyword_count_words( $result['words'] );
                            $is_selected = $words_count >= $min_depth ? true : false;
                            $is_selected == true ? $selected_nb++ : 0;

							$html[] = '<label><input type="checkbox" value="' . ( $result['words'] ) . '" name="WooZonePNF-keyword-checkbox" class="WooZonePNF-keyword-checkbox" ' . ( $is_selected ? 'checked' : '' ) . ' /> ' . ( $result['words'] ) . '</label>';
							
							//$cc++;
						}
					}
					
					$html[] = 			'</td>';
					$html[] = 		'</tr>';
					$html[] = 	'</table>';
					
					$row++;
				}
				
				$html[] = 	'</div>';
				$html[] = 	'<div class="WooZonePNF-products-buttons">';
				$html[] = 		'<div class="WooZonePNF-message WooZonePNF-success">Import <strong id="WooZonePNF-count-keywords">' . ( $selected_nb ) . '</strong> keywords for you content:</div>';
				$html[] = 		'<div class="WooZonePNF-product-found-button-action"><a href="#" class="WooZonePNF-button WooZonePNF-small green WooZonePNF-import-keywords-now" data-postid="' . ( $post_id ) . '">Import Now</a></div>';
				$html[] = 	'</div>';
			}
			
			$html[] = 	'</div>';
			$html[] = '</div>';
			
			die( json_encode( array( 
				'status' => $status,
				'html' 	=> implode( "\n", $html )
			) ) );
		}
		
		public function find_products_into_content( $products=array(), $post_id=0 )
		{
			$degub_level = isset($_REQUEST['debug_level']) ? $_REQUEST['debug_level'] : 0;
			$base = array();
	        $post_content = $this->get_body( $post_id );
			
			require_once $this->parent->path( 'HELPERS_DIR', 'keywords2content.php' );
			$WooZonePNF_keywords2content = new WooZonePNF_keywords2content();
			$founds = $WooZonePNF_keywords2content->make_all( $products, $post_content, 1);
			if( $degub_level == 1 ){
				var_dump('<pre>', $founds,'</pre>'); die;  
			}
			
			$this->choose_from_founds( $founds, $post_id );
			
			if( count($founds) == 0 ){
				die( json_encode( array( 
					'status' => 'not-find',
					'products' => $products
				) ) );
			}
		}

        public function import_keywords()
        {
            $keywords = isset($_REQUEST['keywords']) ? $_REQUEST['keywords'] : array();
            $post_id = isset($_REQUEST['post_id']) ? $_REQUEST['post_id'] : 0;
            
            if( isset($keywords) && count($keywords) > 0 ){
                
                $insert_items_ids = array();
                foreach ($keywords as $combination) {
                    $status = $this->parent->keywords->save( 'save-modify', $combination );
                    $insert_items_ids[] = $status['new_id'];
                    $insert_items_status[] = $status;
                }

                if( count($insert_items_ids) > 0 ){
                    update_post_meta( $post_id, '_WooZonePNF_auto_detect_amz_products', $insert_items_ids );
                }
            }

            die( json_encode( array( 
                'status' => 'valid',
                'text'   => 'Keyword imported successfully.',
                'html'   => $this->auto_fill_manage_container( $post_id )
            ) ) );
        }

		public function _ajax_fetch_search_for_context()
		{
			$post_id = isset($_REQUEST['post_id']) ? (int) $_REQUEST['post_id'] : 0;
			$strip_tags = isset($_REQUEST['strip_tags']) ? (int) $_REQUEST['strip_tags'] : 0;
			$response = $this->get_body( $post_id, $strip_tags );
	        
			//$region = WooZonePNF_Envato_Helper()->get_region();  
    		$response .= 
    		'<script type="text/javascript" language="javascript">
				amzn_assoc_ad_type = "contextual";
				amzn_assoc_tracking_id = "fakeclient-20";
				amzn_assoc_marketplace = "amazon";
				amzn_assoc_region = "US";
				amzn_assoc_emphasize_categories = "";
				amzn_assoc_fallback_products = "";
				amzn_assoc_width = "300";
				amzn_assoc_height = "250";
			</script>
			<script type="text/javascript" language="javascript" src="//z-na.amazon-adsystem.com/widgets/q?ServiceVersion=20070822&Operation=GetScript&ID=OneJS&WS=1&MarketPlace=US&source=ac"></script>
    		';
			
			die( $response );
		}
		
		public function _ajax_fetch_list_table()
		{
			$list_table = new WooZonePNF_auto_find_List_Table();
			$list_table->ajax_response();
		}
		
        private function print_error($msg = "")
        {
            //!!!TMP
            echo ($msg);
        }
        
        public function _ajax_save_hits()
        {
            $keywords = isset($_REQUEST['keywords']) ? (array) $_REQUEST['keywords'] : array();
            $keywords = array_keys($keywords);
            $kw = implode(',', array_map(array(WooZonePNF(), 'prepareForInList'), $keywords));

            $this->wpdb->query( "UPDATE `" . ( $this->config['db_name'] ) . "` SET hits=hits+1 WHERE keyword IN ($kw)" );

            die( json_encode( array( 
                'status' => 'valid',
                'text'   => 'Keywords save hits.',
            ) ) );
        }
    }
}