<?php
if ( ! class_exists( 'WP_List_Table' ) )
	require_once( ABSPATH . 'wp-admin/includes/class-wp-list-table.php' );


/* Hide notices to avoid AJAX errors
 * Sometimes the Class throws a notice about 'hook_suffix' being undefined,
 * which breaks every AJAX call.
 */

class WooZonePNF_Auto_Find_List_Table extends WP_List_Table 
{
	public $data = array();

	private $wpdb = null;
	public $config = array();
	private $post_type = '';
	private $filters = '';
	public $_args = array();
	public $_pagination_args = array();
	
	/**
	 * REQUIRED. Set up a constructor that references the parent constructor. We 
	 * use the parent reference to set some default configs.
	 */
	public function __construct() 
	{
		global $status, $page, $wpdb, $screen;
        
        $settings = WooZonePNF_Envato_Helper()->config;
	
		// This is used only if making any database queries
		$this->wpdb = $wpdb;
		
		// store database name
		$this->config['db_name'] = $this->wpdb->prefix . 'posts';
		
		// how many records per page to show
		$this->config['per_page'] = isset($settings['rows_per_page']) ? (int) $settings['rows_per_page'] : 5;
		
		// Set parent defaults
		parent::__construct(
			array(
				// singular name of the listed records
				'singular'	=> 'auto-find',
				// plural name of the listed records
				'plural'	=> 'auto-find',
				// does this table support ajax?
				'ajax'		=> true,
				'screen'      => 'auto-find' 
			)
		);
		
		$this->post_type = 'post';
		$this->filters = isset($_REQUEST['filter_by']) ? $_REQUEST['filter_by'] : 'post';
		
		$this->_pagination_args['order'] = 'DESC';
		$this->_pagination_args['orderby'] = 'id';
	}
	
	public function column_title( $item )
	{ 
		// Build row actions
		$actions = array(
			'view' 			=> '<a href="' . ( get_permalink(  $item['ID']) ) . '" target="_blank">View</a>',
			'remove_all' 	=> '<a href="#remove_all">Remove All Keywords</a>'
		);
		
		// Return the title contents
		return sprintf('%1$s%2$s',
			/*$1%s*/ $item['post_title'],
			/*$3%s*/ $this->row_actions( $actions )
		);
	}
	
	public function column_default( $item, $column_name )
	{
		switch ( $column_name ) {

			case 'title':
				return $item['post_title'];
			case 'keywords-and-product':
				return WooZonePNF()->autofind->auto_fill_manage_container( $item['ID'] );
			default:
				//Show the whole array for troubleshooting purposes
				return print_r( $item, true );
		}
	}
	
	public function display_tablenav( $which ) 
	{
	    ?>
	    <div class="tablenav <?php echo esc_attr( $which ); ?>">
	        
	        <div class="alignleft actions">
	            <select name="filter_by">
	            	<?php
	            	foreach ($this->get_bulk_actions() as $key => $value) {
						echo '<option value="' . ( $key ) . '" ' . ( $key == $this->filters ? 'selected="selected"' : '' ) . '>' . ( $value ) . '</option>';
					}
	            	?>
				</select>
				<input name="" id="doaction" class="button action" value="Apply" type="submit">
	        </div>
	        
	        <?php
	        $this->extra_tablenav( $which );
	        $this->pagination( $which );
	        ?>
	        <br class="clear" />
	    </div>
	    <?php
	}
	
	public function column_cb( $item )
	{
		return sprintf(
			'<input type="checkbox" name="%1$s[]" value="%2$s" />',
			/*$1%s*/ $this->_args['singular'], 
			/*$2%s*/ $item['ID']
		);
	}

	public function get_columns()
	{
		return $columns = array(
			'title'					=> 'Title',
			'keywords-and-product'	=> 'Keywords and products'
		);
	}

	public function get_sortable_columns()
	{
		// true means it's already sorted
		return $sortable_columns = array(
			'title'	 		=> array( 'keyword', false )
		);
	}

	public function get_bulk_actions()
	{
		$array = array();
		$post_types = get_post_types(array(
			'public' => true
		));
		foreach ($post_types as $post_type) {
			if( in_array($post_type, array('page', 'attachment') ) ) continue;
			$post_counts = wp_count_posts( $post_type ); 
			$array[$post_type] = "(" . ( $post_counts->publish ) . ") " . ucfirst( $post_type );
		}  
		return $array;
	}

	public function prepare_items() 
	{
		
		if( $this->filters  != "" ){
			$this->post_type = $this->filters ;
		}
		
		$columns = $this->get_columns();
		$hidden = array();
		$sortable = $this->get_sortable_columns();
		
		$this->_column_headers = array( $columns, $hidden, $sortable );
		
		$total_items = $this->wpdb->get_var( "SELECT COUNT(id) FROM " . $this->config['db_name'] . " WHERE 1=1 AND post_status='publish' AND post_type='" . ( $this->post_type ) . "'" );
 
	    $paged = isset($_REQUEST['paged']) ? max(0, intval($_REQUEST['paged']) - 1) : 0;
	    $orderby = (isset($_REQUEST['orderby']) && in_array($_REQUEST['orderby'], array_keys($this->get_sortable_columns()))) ? $_REQUEST['orderby'] : 'id';
	    $order = (isset($_REQUEST['order']) && in_array($_REQUEST['order'], array('asc', 'desc'))) ? $_REQUEST['order'] : 'desc';
	
		$offset = $paged * $this->config['per_page']; 
	    $this->items = $this->wpdb->get_results($this->wpdb->prepare("SELECT * FROM " . ( $this->config['db_name'] ) . " WHERE 1=1 AND post_status='publish' AND post_type='" . ( $this->post_type ) . "' ORDER BY $orderby $order LIMIT %d OFFSET %d", $this->config['per_page'], $offset), ARRAY_A);
 
		// REQUIRED for pagination
		$current_page = $this->get_pagenum();
		
		// register our pagination options & calculations.
		$this->set_pagination_args(
			array(
				// WooZonePNF have to calculate the total number of items
				'total_items'	=> $total_items,
				// WooZonePNF have to determine how many items to show on a page
				'per_page'	=> $this->config['per_page'],
				// WooZonePNF have to calculate the total number of pages
				'total_pages'	=> ceil( $total_items / $this->config['per_page'] ),
				// Set ordering values if needed (useful for AJAX)
				'orderby'	=> ! empty( $_REQUEST['orderby'] ) && '' != $_REQUEST['orderby'] ? $_REQUEST['orderby'] : 'id',
				'order'		=> ! empty( $_REQUEST['order'] ) && '' != $_REQUEST['order'] ? $_REQUEST['order'] : 'desc'
			)
		);
	}

	/**
	 * Display the table
	 * Adds a Nonce field and calls parent's display method
	 *
	 * @since 3.1.0
	 * @access public
	 */
	public function display()
	{ 
		//wp_nonce_field( 'ajax-custom-list-nonce', '_ajax_custom_list_nonce' );
		
		echo '<input type="hidden" id="ajaxid" name="ajaxid" value="WooZonePNF_auto_find_list_table" />';
		echo '<input type="hidden" id="WooZonePNF_action" name="WooZonePNF_action" value="auto-find" />';
		echo '<input type="hidden" id="order" name="order" value="' . $this->_pagination_args['order'] . '" />';
		echo '<input type="hidden" id="orderby" name="orderby" value="' . $this->_pagination_args['orderby'] . '" />';

		parent::display();
	}

	/**
	 * Handle an incoming ajax request (called from admin-ajax.php)
	 *
	 * @since 3.1.0
	 * @access public
	 */
	public function ajax_response() 
	{
		$this->prepare_items();

		extract( $this->_args );
		extract( $this->_pagination_args, EXTR_SKIP );

		ob_start();
		if ( ! empty( $_REQUEST['no_placeholder'] ) )
			$this->display_rows();
		else
			$this->display_rows_or_placeholder();
		$rows = ob_get_clean();

		ob_start();
		$this->print_column_headers();
		$headers = ob_get_clean();

		ob_start();
		$this->pagination('top');
		$pagination_top = ob_get_clean();

		ob_start();
		$this->pagination('bottom');
		$pagination_bottom = ob_get_clean();

		$response = array( 'rows' => $rows );
		$response['pagination']['top'] = $pagination_top;
		$response['pagination']['bottom'] = $pagination_bottom;
		$response['column_headers'] = $headers;

		if ( isset( $total_items ) )
			$response['total_items_i18n'] = sprintf( _n( '1 item', '%s items', $total_items ), number_format_i18n( $total_items ) );

		if ( isset( $total_pages ) ) {
			$response['total_pages'] = $total_pages;
			$response['total_pages_i18n'] = number_format_i18n( $total_pages );
		}

		die( json_encode( $response ) );
	}
}