<?php
/**
 * Amazon Helper module
 * http://www.aa-team.com
 * ======================
 *
 * @package		WooEnvato Contextual
 * @author		Andrei Dinca, AA-Team
 * @version		1.0
 */
!defined('ABSPATH') and exit;
if (class_exists('AHLG_Import_Helper') != true) {
    class AHLG_Import_Helper
    {
        const VERSION = '1.0';
		
		public $country_data = array();
		
        /**
         * parent storage
         *
         * @var array
         */
        public $config = array(
			"api_key" => ""
		);
		
		private $trys = 3;

		public $aaAmazonWS = null;
        public $amz_setup = array();
        
        /**
         * The constructor
         */
        public function __construct()
        {
        	// create AJAX request
			add_action('wp_ajax_AHLG_ajax', array(
                $this,
                'ajax_requests'
            ));
        }
		
		private function print_error_response( $msg='' )
		{	
			die( json_encode( array(
				'status' 	=> 'invalid',
				'msg'		=> $msg
			) ) );  
		}
		
		private function items_as_html( $items=array() )
		{
			$html = array();
			if( count($items) > 0 ){

				$ret_products[] = array(
					'ASIN' 			=> isset($product['ASIN']) ? $product['ASIN'] : '',
					'Title' 		=> isset($product['ItemAttributes']['Title']) ? $product['ItemAttributes']['Title'] : '',
					'SalesRank' 	=> isset($product['SalesRank']) ? $product['SalesRank'] : '',
					'Binding'	 	=> isset($product['ItemAttributes']['Binding']) ? $product['ItemAttributes']['Binding'] : '',
					'Brand' 		=> isset($product['ItemAttributes']['Brand']) ? $product['ItemAttributes']['Brand'] : '',
					'SmallImage' 	=> isset($product['SmallImage']['URL']) ? $product['SmallImage']['URL'] : '',
					'MediumImage' 	=> isset($product['MediumImage']['URL']) ? $product['MediumImage']['URL'] : '',
					'LargeImage' 	=> isset($product['LargeImage']['URL']) ? $product['LargeImage']['URL'] : ''
				);
				
				foreach ($items as $product) {
					$html[] = '<li';
					$html[] = 'data-asin="' . ( $product['ASIN'] ) . '" ';
					$html[] = 'data-title="' . ( esc_attr( $product['Title'] ) ) . '" ';
					$html[] = 'data-salesrank="' . ( esc_attr( $product['SalesRank'] ) ) . '" ';
					$html[] = 'data-binding="' . ( esc_attr( $product['Binding'] ) ) . '" ';
					$html[] = 'data-brand="' . ( esc_attr( $product['Brand'] ) ) . '" ';
					$html[] = 'data-smallimage="' . ( esc_attr( $product['SmallImage'] ) ) . '" ';
					$html[] = 'data-mediumimage="' . ( esc_attr( $product['MediumImage'] ) ) . '" ';
					$html[] = 'data-largeimage="' . ( esc_attr( $product['LargeImage'] ) ) . '" ';
					$html[] = '>';
					
					$html[] = 	'<span class="AHLG-checked-product AHLG-selected">
								<input type="checkbox" name="check" checked>
								<span>
									<i class="fa fa-check"></i>
									<i class="fa fa-minus"></i>
								</span>
							</span>';

					
					$html[] = 	'<a target="_blank" href="" style="background-image: url(' . ( $product['MediumImage'] ) . ')" class="WZC-keyword-attached-image"></a>';
					$html[] = 	'<div class="WZC-keyword-attached-title">' . ( $product['Title'] ) . '</div>';
					$html[] = 	'<div class="WZC-keyword-attached-rank">' . ( $product['SalesRank'] ) . '</div>';
					$html[] = '</li>';
				}
			}
			
			return implode( "\n", $html );
		}
		
		public function soft_trim( $text, $count, $wrapText='...' )
		{
		    if(strlen($text)>$count){
		        preg_match('/^.{0,' . $count . '}(?:.*?)\b/siu', $text, $matches);
		        $text = $matches[0];
		    }else{
		        $wrapText = '';
		    }
		    return $text . $wrapText;
		}
		
		private function no_results( $params=array() )
		{
			$html = array(); 

			//$html[] = '<div class="AHLG_iw-status-error">';
			$html[] = 'No results found! ';
			if( count($params) > 0 ){
				$html[] = 'Parameters for your search was:';
				foreach ($params as $key => $value) {
					$html[] = "$key: $value, ";
				}
			}

			//$html[] = '</div>';

			die(json_encode(array(
				'status' => 'invalid',
				'msg' => implode(" ", $html)
			)));
		}
		
		public function ajax_requests()
		{
			$action = isset($_REQUEST['sub_action']) ? $_REQUEST['sub_action'] : 'none';
			
			$valid_actions = array(
				'BrowseNodeLookup', 
				'ItemSearch',
				'import-product'
			);

			$params = isset($_REQUEST['params']) ? $_REQUEST['params'] : array();
			if( in_array($action, $valid_actions) ){

				if( $action == 'import-product' ){

					$product = isset($_REQUEST['product']) ? $_REQUEST['product'] : array();
					$cat_name = isset($product['binding']) ? $product['binding'] : '';

					$availables =  AHLG()->get_product_available( $product['asin'] );
					$rating = AHLG()->get_product_ratings( $product['asin'] );

					// Create post object
					$product = array(
					  'post_title'    => wp_strip_all_tags( $product['title'] ),
					  'post_status'   => 'publish',
					  'post_author'   => get_current_user_id(),
					  'post_type'	  => 'amzproducts',
					  'meta_input'   => array(
					        'asin' 			=> $product['asin'],
					        'country' 		=> AHLG()->amz_setup['country'],
					        'salesrank' 	=> $product['salesrank'],
					        'binding' 		=> $product['binding'],
					        'brand' 		=> $product['brand'],
					        'rating' 		=> $rating['rating'],
					        'totals_rate' 	=> $rating['totals'],
					        'smallimage' 	=> $product['smallimage'],
					        'mediumimage' 	=> $product['mediumimage'],
					        'largeimage' 	=> $product['largeimage'],
					        'availabes'		=> $availables
					    ),
					);
					 
					// Insert the post into the database
					$post_id = wp_insert_post( $product );

					$taxonomy = 'amzproductcategs'; // category by default for posts for other custom post types like woo-commerce it is product_cat
					$append = true ;// true means it will add the cateogry beside already set categories. false will overwrite

					//get the category to check if exists
					$cat  = get_term_by( 'name', $cat_name , $taxonomy );

					// check existence
					if( $cat == false ){

					    //cateogry not exist create it 
					    $cat = wp_insert_term( $cat_name, $taxonomy );

					    //category id of inserted cat
					    $cat_id = $cat['term_id'] ;

					}else{

					    //category already exists let's get it's id
					    $cat_id = $cat->term_id ;
					}

					// setting post category 
					$res = wp_set_post_terms( $post_id, array($cat_id),$taxonomy ,$append );

					die( json_encode(array(
						'status' 	=> 'valid'
					)) );
				}

				if( $action == 'BrowseNodeLookup' ){
  					
  					try {
					    $childrens = AHLG()->aaAmazonWS->responseGroup( 'BrowseNodeInfo' )->browseNodeLookup( $params['browse_node'] );		
					} catch (Exception $e) {

						die(json_encode(array(
							'status' => 'invalid',
							'msg' => $e->faultstring
						)));
					}
					
					if( $childrens ){
						if( isset($childrens['BrowseNodes']['Request']['IsValid']) && $childrens['BrowseNodes']['Request']['IsValid'] == true ){

							$html = array();
							if( count($childrens["BrowseNodes"]['BrowseNode']['Children']['BrowseNode']) > 0 ){
								$html[] = '<select class="parameter" name="sub-categs" style="width: 200px">';
								
								foreach ($childrens["BrowseNodes"]['BrowseNode']['Children']['BrowseNode'] as $key => $value) {
									$html[] = '<option value="#|' . ( $value['BrowseNodeId'] ) . '">' . ( $value['Name'] ) . '</option>';
								}

								$html[] = '</select>';
							}else{
								$this->no_results();
							}
						}else{
							$this->no_results();
						}
					}else{
						$this->no_results();
					}
					
					die( json_encode(array(
						'status' 	=> 'valid',
						'html'		=> implode( "\n", $html )
					)) );
				} 

				if( $action == 'ItemSearch' ){
					parse_str( $params, $params );

					$__categ = explode( "|", $params['categs'] );

					try {
					    $products = AHLG()->aaAmazonWS->responseGroup( 'SalesRank,Medium' )->category( $__categ[0] )->browseNode( $__categ[1] )->search( $params['keywords'] );		
					} catch (Exception $e) {

						die(json_encode(array(
							'status' => 'invalid',
							'msg' => $e->faultstring
						)));
					  	//var_dump('<pre>',$e ,'</pre>'); echo __FILE__ . ":" . __LINE__;die . PHP_EOL;  
					}

					$html = array();
					if( $products ){
						$ret_products = array();	
						if( isset($products['Items']['Request']['IsValid']) && $products['Items']['Request']['IsValid'] == true ){

							if( isset($products['Items']['Item']) && count($products['Items']['Item']) > 0 ){
								foreach ($products['Items']['Item'] as $product) {
									if( isset($product['SalesRank']) && trim($product['SalesRank']) != "" && (int)$product['SalesRank'] > 0 ){
										$ret_products[] = array(
											'ASIN' 			=> isset($product['ASIN']) ? $product['ASIN'] : '',
											'Title' 		=> isset($product['ItemAttributes']['Title']) ? $product['ItemAttributes']['Title'] : '',
											'SalesRank' 	=> isset($product['SalesRank']) ? $product['SalesRank'] : '',
											'Binding'	 	=> isset($product['ItemAttributes']['Binding']) ? $product['ItemAttributes']['Binding'] : '',
											'Brand' 		=> isset($product['ItemAttributes']['Brand']) ? $product['ItemAttributes']['Brand'] : '',
											'SmallImage' 	=> isset($product['SmallImage']['URL']) ? $product['SmallImage']['URL'] : '',
											'MediumImage' 	=> isset($product['MediumImage']['URL']) ? $product['MediumImage']['URL'] : '',
											'LargeImage' 	=> isset($product['LargeImage']['URL']) ? $product['LargeImage']['URL'] : ''
										);
									}
								}

								if( count($ret_products) > 0 ){
									$html = $this->items_as_html( $ret_products );
								}else{
									$this->no_results();
								}
							}else{
								$this->no_results();
							}
						}else{ 
							$this->no_results();
						}
					}else{
						$this->no_results();
					}

					die( json_encode(array(
						'status' 	=> 'valid',
						'html'		=> $html
					)) );
				}
			}

			die("Invalid Action!");

			var_dump('<pre>',$action ,'</pre>'); 
			echo __FILE__ . ":" . __LINE__;die . PHP_EOL;   
			$this->no_results( $params );

			die('Error');
		}
	}
}
