<?php
/**
 * Amazon Helper module
 * http://www.aa-team.com
 * ======================
 *
 * @package		WooZone Contextual
 * @author		Andrei Dinca, AA-Team
 * @version		1.0
 */
!defined('ABSPATH') and exit;
if (class_exists('WooZonePNF_CP_Movie_Import') != true) {
    class WooZonePNF_CP_Movie_Import
    {
        const VERSION = '1.0';
		
		public $item = array();
		public $post_id = 0;
		
		public $config = array();
		private $async_images = array();

        /**
         * The constructor
         */
        public function __construct( $item=array() )
        {
        	$this->item = $item;

        	//$this->check_for_duplicate();
			
			$this->load_config();
        }
		
		public function update_setup( $settings=array() )
		{
			if( $settings && count($settings) > 0 ){
				$this->config = array_merge( $this->config, $settings );
			}
		}
		
		public function load_config()
		{
			$config_file = WooZonePNF()->wp_filesystem->get_contents( realpath(dirname(__FILE__)) . '/tmbd-configuration.json' );
			$this->config = json_decode( $config_file, true ); 
		}
		
		public function style_post_content( $content )
		{
			if( $content != "" ){
				return wpautop( $content );
			}
			
			return $content;
		}
		
		public function get_meta_values( $key = '', $value = 'post' )
		{
		    global $wpdb;
		
		    if( empty( $key ) )
		        return;
			
			$r = $wpdb->get_row( $wpdb->prepare( "
		        SELECT * FROM {$wpdb->postmeta}
		        WHERE 1=1 AND meta_key = '%s' AND meta_value = '%s'
		    ", $key, $value ), ARRAY_A );
			
			//var_dump('<pre>',$wpdb,'</pre>'); die;  
		    return $r;
		}

		public function remove_unuset_sizez( $sizes ) 
		{ 
			if( isset($_REQUEST['sub_action']) && $_REQUEST['sub_action'] == 'import-image' ){
				if( count($sizes) > 0 ){
					
					$where = isset($_REQUEST['where']) ? $_REQUEST['where'] : '';
					foreach ($sizes as $key => $value) {
						if( $where == "poster" ){
							if( !in_array( $key, array( 'movies-thumb', 'movies-big-thumb', 'movies-featured-image' ) )){
								unset( $sizes[$key] );
							}
						}

						if( $where == "backdrops" ){
							if( !in_array( $key, array( 'thumbnail', 'movies-gallery' ) )){
								unset( $sizes[$key] );
							}
						}

						if( $where == "profile" ){
							if( !in_array( $key, array( 'movies-cast-thumb' ) )){
								unset( $sizes[$key] );
							}
						}
					}
				}
			}

			return $sizes;
		}
		
		public function set_product_images( $post_id=0, $img_url='', $where='', $term_id=0 )
		{
			if ( ! empty($img_url) ) {
				
				// get file name 
				$file_name = parse_url( $img_url );
				$file_sum = md5( $file_name['path'] );
				
				// check if we already have this image into db
				$tmdb_assets = $this->get_meta_values( '_tmdb_assets', $file_sum );
				
				if( !$tmdb_assets ){
		            // download file to temp location
		            $tmp = download_url( $img_url );

		            add_filter( 'intermediate_image_sizes_advanced', array( $this, 'remove_unuset_sizez'), 10 );

		            // fix file filename for query strings
		            preg_match('/[^\?]+\.(jpg|JPG|jpe|JPE|jpeg|JPEG|gif|GIF|png|PNG)/', $img_url, $matches);
		            $file_array['name'] = basename($matches[0]);
		            $file_array['tmp_name'] = $tmp;
		 
		            // if error storing temporarily, unlink
		            if ( is_wp_error( $tmp ) ) {
		                @unlink($file_array['tmp_name']);
		                $file_array['tmp_name'] = '';
		            }
 
		            // do the validation and storage stuff
		            $thumbid = media_handle_sideload( $file_array, $post_id, '' );

		            // If error storing permanently, unlink
		            if ( is_wp_error($thumbid) ) {
		                @unlink($file_array['tmp_name']);
		                return $thumbid;
		            }
	
					// update the asset into db
					update_post_meta( $thumbid, '_tmdb_assets', $file_sum );

				}
				else{
					$thumbid = $tmdb_assets['post_id'];
				}
	        }

			if( $where == 'poster' ){
				set_post_thumbnail( $post_id, $thumbid );
			}
			
			if( $where == 'backdrops' ){
				// get original product gallery
				$prod_gallery = get_post_meta( $post_id, "_movie_image_gallery" );
				$prod_gallery[] = $thumbid;
				
				// update the product image gallery
				update_post_meta( $post_id, "_movie_image_gallery", implode(',', $prod_gallery) );
			}
			
			if( $where == 'profile' ){
				update_term_meta( $term_id, '_thumbnail', absint( $thumbid ) );
			}

			die(json_encode( array(
				'status' => 'valid'
			)));
		}
		
		private function check_for_duplicate()
		{
			$args = array(
			    'posts_per_page'   	=> -1,
			    'orderby'          	=> 'post_date',
			    'order'            	=> 'DESC',
			    'post_type' 		=> "movies",
			    'post_status'      	=> 'publish',
			    'meta_query' => array(
			        array(
			            'key'     => '_imdb_id',
			            'value'   => $this->item['imdb_id'],
			            'compare' => '==',
			        ),
			    ),
			);
			
			$duplicate_posts = get_posts( $args );
			if( count($duplicate_posts) > 0 && isset($duplicate_posts[0]) ){
				if( isset($duplicate_posts[0]->ID) ){
					die( json_encode( array(
						'status' 	=> 'product_duplicate',
						'post_id'	=> $duplicate_posts[0]->ID
					) ) );
				}
			}

			//return array( 'status' => 'new_product' );
		}
		
		private function add_trailers()
		{
			if( isset($this->item['trailers']) ){
				$db_trailers = array();
				// youtube case
				if( isset($this->item['trailers']['youtube']) && count($this->item['trailers']['youtube']) > 0 ){
					foreach ($this->item['trailers']['youtube'] as $trailer) {
						$db_trailers[] = array(
							'type' 	=> 'youtube',
							'id' 	=> $trailer['source'],
							'title' => $trailer['name'],
							'thumb' => 'http://img.youtube.com/vi/' . ( $trailer['source'] ) . '/mqdefault.jpg',
						);
					}
				}
				
				if( count($db_trailers) > 0 ){
					update_post_meta( $this->post_id, "_tmdb_pt_movie_trailers", $db_trailers );
				}
			}
		}
		
		private function add_rating()
		{
			if( isset($this->item['popularity']) ){
				if( (float) $this->item['popularity'] > 0 ){
					update_post_meta( $this->post_id, "_tmdb_pt_movie_popularity", $this->item['popularity'] );
				}
			}
		}
		
		private function tails_poster()
		{
			if( isset($this->item['poster_path']) ){
				$this->async_images[] = array(
					'thumb' => $this->config['images']['base_url'] . 'w154' . $this->item['poster_path'],
					'full' 	=> $this->config['images']['base_url'] . $this->config['poster_size'] . $this->item['poster_path'],
					'where' => 'poster'
				);
			}
		}
		
		private function add_cast()
		{
			
			if( isset($this->item['casts']) && isset($this->item['casts']['cast']) ){
				
				if( count($this->item['casts']['cast']) > 0 ){
					if( (int)$this->config['cast_nb'] > 0 ) {
						$this->item['casts']['cast'] = array_slice( $this->item['casts']['cast'], 0, $this->config['cast_nb']);
					}
					$post_cast = array();
					$term_tax_ids = array();

					foreach ($this->item['casts']['cast'] as $cast) {

						$term_exist = get_term_by( 'name', $cast['name'], 'cast', ARRAY_A );
						$term_tax_ids[] = $term_exist['term_id'];
						if ( !$term_exist ) {
							 
							$term_exist = wp_insert_term( $cast['name'], 'cast' );
							$term_tax_ids[] = $term_exist['term_id'];
							if( isset($cast['profile_path']) && trim($cast['profile_path']) != "" ){
								$this->async_images[] = array(
									'thumb' 	=> $this->config['images']['base_url'] . 'w300' . $cast['profile_path'],
									'full' 		=> $this->config['images']['base_url'] . 'w300' . $cast['profile_path'],
									//'full' 		=> $this->config['images']['base_url'] . $this->config['backdrop_sizes'] . $cast['profile_path'],
									'where' 	=> 'profile',
									'term_id' 	=> $term_exist['term_id']
								);
							}
						}

						$post_cast[] = array(
							'term_id'   => $term_exist['term_id'],
							'character' => $cast['character']
						);
					}
					
					
					// set the term relations
					$term_taxonomy_ids = wp_set_object_terms( $this->post_id, $term_tax_ids, 'cast' );

					// set the post cast terms
					update_post_meta( $this->post_id, '_omb_cast', $post_cast );
					
					return $term_exist;
				}
			}
		}

		private function tails_backdrops()
		{
			if( isset($this->item['images']) && isset($this->item['images']['backdrops']) ){
				if( count($this->item['images']['backdrops']) > 0 ){
					
					if( (int)$this->config['backdrop_nb'] > 0 ) {
						$this->item['images']['backdrops'] = array_slice( $this->item['images']['backdrops'], 0, $this->config['backdrop_nb']);
					}
					
					foreach ($this->item['images']['backdrops'] as $poster) {
						$this->async_images[] = array(
							'thumb' => $this->config['images']['base_url'] . 'w300' . $poster['file_path'],
							'full' 	=> $this->config['images']['base_url'] . $this->config['backdrop_sizes'] . $poster['file_path'],
							'where' => 'backdrops'
						);
					}
				}
			}
		}
		
		public function add_genres()
		{
			if( isset($this->item['genres']) && count($this->item['genres']) > 0 ){
				
				$term_tax_ids = array();
				foreach ($this->item['genres'] as $genre) {
					$term_exist = get_term_by( 'name', $genre['name'], 'genre', ARRAY_A );
					$term_tax_ids[] = $term_exist['term_id'];
					if ( !$term_exist ) {
						$term_exist = wp_insert_term( $genre['name'], 'genre' );
						$term_tax_ids[] = $term_exist['term_id'];
					}
				}
				
				// set the term relations
				$term_taxonomy_ids = wp_set_object_terms( $this->post_id, $term_tax_ids, 'genre' );
			}
		}
		
		public function add_extra()
		{
			if( isset($this->item['homepage']) ) 				add_post_meta( $this->post_id, "_homepage", $this->item['homepage'] );
			if( isset($this->item['rated']) ) 					add_post_meta( $this->post_id, "_rated", $this->item['rated'] );
			if( isset($this->item['director']) ) 				add_post_meta( $this->post_id, "_director", $this->item['director'] );
			if( isset($this->item['actors']) ) 					add_post_meta( $this->post_id, "_actors", $this->item['actors'] );
			if( isset($this->item['imdb_rating']) ) 			add_post_meta( $this->post_id, "_imdb_rating", $this->item['imdb_rating'] );
			if( isset($this->item['budget']) ) 					add_post_meta( $this->post_id, "_budget", $this->item['budget'] );
			if( isset($this->item['imdb_id']) ) 				add_post_meta( $this->post_id, "_imdb_id", $this->item['imdb_id'] );
			if( isset($this->item['production_companies']) ) 	add_post_meta( $this->post_id, "_production_companies", $this->item['production_companies'] );
			if( isset($this->item['release_date']) ) 			add_post_meta( $this->post_id, "_release_date", $this->item['release_date'] );
			if( isset($this->item['tagline']) ) 				add_post_meta( $this->post_id, "_tagline", $this->item['tagline'] ); 
			if( isset($this->item['runtime']) ) 				add_post_meta( $this->post_id, "_runtime", $this->item['runtime'] ); 
			if( isset($this->item['id']) ) 						add_post_meta( $this->post_id, "_tmdb_id", $this->item['id'] ); 

			add_post_meta( $this->post_id, "_WooZonePNF_movie_hits", 0 ); 
		}
		
		private function autocommit( $action="start" )
		{
			global $wpdb;

			if( $action == 'start' ){
				$wpdb->query( 'SET autocommit = 0;' );
			}

			if( $action == 'end' ){
				$wpdb->query( 'COMMIT;' );
			}
		}

		public function import_item()
		{
			$this->autocommit( 'start' );

			$post = array(
		    	'post_author' => get_current_user_id(),
		    	'post_content' => $this->style_post_content( $this->item['overview'] ),
		    	'post_status' => "publish",
		    	'post_title' => $this->item['title'],
		    	'post_type' => "movies",
			);

		    // create the post
		    $this->post_id = wp_insert_post( $post );

		    if( isset(WooZonePNF()->settings['search_for_related_products']) && WooZonePNF()->settings['search_for_related_products'] == 'true' ){

			    // add amazon products
			    $tmdbMovies = tmdbMovies::getInstance();
			    $amazon_products = $tmdbMovies->get_amazon_products( $this->post_id, $this->item['title'], 'com', 'json' );
		    }
   
			// add trailers
			$this->add_extra();

			// add trailers
			$this->add_genres();
			
			// add trailers
			$this->add_trailers();
			
			// add poster to tails
			$this->tails_poster();

			// add backdrops to tails
			$this->tails_backdrops();

			// add cast
			$this->add_cast();

			$this->autocommit( 'end' );

			die( json_encode( array(
				'status' 		=> 'valid',
				'post_id' 		=> $this->post_id,
				'asyn_images' 	=> $this->async_images
			))); 
		}
	}
}