<?php
/**
 * WooZonePNF Main manager.
 *
 * @package WooZonePNF
 * @since   1.0
 */
if ( ! function_exists( 'WooZonePNF' ) ) {
	/**
	 * WooZonePNF manager.
	 * @since 1.0
	 * @return WooZonePNF
	 */
	function WooZonePNF() {
		global $WooZonePNF;

		return $WooZonePNF;
	}
}

if ( ! function_exists( 'WooZonePNF_Settings' ) ) {
	/**
	 * WooZonePNF manager.
	 * @since 1.0
	 * @return WooZonePNF_Settings
	 */
	function WooZonePNF_Settings() {
		return new WooZonePNF_Settings();
	}
}

if ( ! function_exists( 'WooZonePNF_Social' ) ) {
	/**
	 * WooZonePNF manager.
	 * @since 1.0
	 * @return WooZonePNF_Social
	 */
	function WooZonePNF_Social() {
		return new WooZonePNF_Social();
	}
}

if ( ! function_exists( 'WooZonePNF_Settings_Build_Options' ) ) {
	/**
	 * WooZonePNF manager.
	 * @since 1.0
	 * @return WooZonePNF_Settings
	 */
	function WooZonePNF_Settings_Build_Options( $options=array(), $box_id='' ) {
		return WooZonePNF_Settings()->build_options( $options, $box_id );
	}
}

/*
if ( ! function_exists( 'WooZonePNF_Envato_Helper' ) ) {
	function WooZonePNF_Envato_Helper() {
		return new WooZonePNF_Envato_Helper();
	}
}*/

if ( ! function_exists( 'WooZonePNF_Woocommerce' ) ) {
	/**
	 * WooZonePNF manager.
	 * @since 1.0
	 * @return WooZonePNF_Settings
	 */
	function WooZonePNF_Woocommerce() {
		return new WooZonePNF_Woocommerce();
	}
}

if ( ! function_exists( 'WooZonePNF_Load_Options' ) ) {
	/**
	 * WooZonePNF manager.
	 * @since 1.0
	 * @return WooZonePNF_Settings
	 */
	function WooZonePNF_Load_Options( $dir ) {
	    new WooZonePNF_Settings(); // save settings first!
	    
		$options = array();
		// find if we have a options.php into the same folder
		$options_file = $dir . '/options.php';
		if( is_file($options_file) ){
			
			ob_start();
			require_once $options_file;
			
			$content = ob_get_contents();
			ob_clean();
 
			if( trim($content) != "" ){
				$options = json_decode( $content, true );
			}
		}
		return $options;
	}
}

if ( ! function_exists( 'WooZonePNF_mapper' ) ) {
	/**
	 * Shorthand for WooZonePNF Mapper.
	 * @since 1.0
	 * @return WooZonePNF_Mapper
	 */
	function WooZonePNF_mapper() {
		return WooZonePNF()->mapper();
	}
}
if ( ! function_exists( 'WooZonePNF_settings' ) ) {
	/**
	 * Shorthand for WooZonePNF settings.
	 * @since 1.0
	 * @return WooZonePNF_Settings
	 */
	function WooZonePNF_settings() {
		return WooZonePNF()->settings();
	}
}
if ( ! function_exists( 'WooZonePNF_path_dir' ) ) {
	/**
	 * Get file/directory path in WooZonePNF.
	 *
	 * @param string $name - path name
	 * @param string $file
	 *
	 * @since 1.0
	 * @return string
	 */
	function WooZonePNF_path_dir( $name, $file = '' ) {
		return WooZonePNF()->path( $name, $file );
	}
}
if ( ! function_exists( 'WooZonePNF_upload_dir' ) ) {
	/**
	 * Temporary files upload dir;
	 * @since 1.0
	 * @return string
	 */
	function WooZonePNF_upload_dir() {
		return WooZonePNF()->uploadDir();
	}
}
if ( ! function_exists( 'WooZonePNF_path_dir' ) ) {
	/**
	 * Get file/directory path in WooZonePNF.
	 *
	 * @param string $name - path name
	 * @param string $file
	 *
	 * @since 4.2
	 * @return string
	 */
	function WooZonePNF_path_dir( $name, $file = '' ) {
		return WooZonePNF()->path( $name, $file );
	}
}
if ( ! function_exists( 'WooZonePNF_post_param' ) ) {
	/**
	 * Get param value from $_POST if exists.
	 *
	 * @param $param
	 * @param $default
	 *
	 * @since 1.0
	 * @return null|string - null for undefined param.
	 */
	function WooZonePNF_post_param( $param, $default = null ) {
		return isset( $_POST[ $param ] ) ? $_POST[ $param ] : $default;
	}
}
if ( ! function_exists( 'WooZonePNF_get_param' ) ) {
	/**
	 * Get param value from $_GET if exists.
	 *
	 * @param $param
	 * @param $default
	 *
	 * @since 1.0
	 * @return null|string - null for undefined param.
	 */
	function WooZonePNF_get_param( $param, $default = null ) {
		return isset( $_GET[ $param ] ) ? $_GET[ $param ] : $default;
	}
}
if ( ! function_exists( 'WooZonePNF_request_param' ) ) {
	/**
	 * Get param value from $_REQUEST if exists.
	 *
	 * @param $param
	 * @param $default
	 *
	 * @since 4.4
	 * @return null|string - null for undefined param.
	 */
	function WooZonePNF_request_param( $param, $default = null ) {
		return isset( $_REQUEST[ $param ] ) ? $_REQUEST[ $param ] : $default;
	}
}
if ( ! function_exists( 'WooZonePNF_action' ) ) {
	/**
	 * Get WooZonePNF special action param.
	 * @since 1.0
	 * @return string|null
	 */
	function WooZonePNF_action() {
		$WooZonePNF_action = 'dashboard';
		if ( isset( $_GET['WooZonePNF_action'] ) ) {
			$WooZonePNF_action = $_GET['WooZonePNF_action'];
		} elseif ( isset( $_POST['WooZonePNF_action'] ) ) {
			$WooZonePNF_action = $_POST['WooZonePNF_action'];
		}

		return $WooZonePNF_action;
	}
}

if ( ! function_exists( 'WooZonePNF_asset_url' ) ) {
	/**
	 * Get full url for assets.
	 *
	 * @param string $file
	 *
	 * @since 4.2
	 * @return string
	 */
	function WooZonePNF_asset_url( $file ) {
		return WooZonePNF()->assetUrl( $file );
	}
}

if ( ! function_exists( 'WooZonePNF_templates_url' ) ) {
	/**
	 * Get full url for assets.
	 *
	 * @param string $file
	 *
	 * @since 4.2
	 * @return string
	 */
	function WooZonePNF_templates_url( $file ) {
		return WooZonePNF()->templatesUrl( $file );
	}
}

if ( ! function_exists( 'WooZonePNF_locate_template' ) ) {
	function WooZonePNF_locate_template( $template_name, $template_path = '', $default_path = '' ) 
	{
	    if ( ! $template_path ) {
	        $template_path = 'templates/';
	    }

	    if ( ! $default_path ) {
	        $default_path = WooZonePNF()->path( 'TEMPLATES_DIR', '' );
	    }
 
	    // Look within passed path within the theme - this is priority.
	    $template = locate_template(
	        array(
	            trailingslashit( $template_path ) . $template_name,
	            $template_name
	        )
	    );

	    // Get default template/
	    if ( ! $template ) {
	        $template = $default_path . $template_name;
	    }

	    // Return what we found.
	    return apply_filters( 'WooZonePNF_locate_template', $template, $template_name, $template_path );
	}
}


if ( ! function_exists( 'WooZonePNF_Get_IP' ) ) {
	function WooZonePNF_Get_IP() 
	{
		//Just get the headers if we can or else use the SERVER global
		if ( function_exists( 'apache_request_headers' ) ) {
			$headers = apache_request_headers();
		} else {
			$headers = $_SERVER;
		}
		//Get the forwarded IP if it exists
		if ( array_key_exists( 'X-Forwarded-For', $headers ) && filter_var( $headers['X-Forwarded-For'], FILTER_VALIDATE_IP, FILTER_FLAG_IPV4 ) ) {
			$the_ip = $headers['X-Forwarded-For'];
		} elseif ( array_key_exists( 'HTTP_X_FORWARDED_FOR', $headers ) && filter_var( $headers['HTTP_X_FORWARDED_FOR'], FILTER_VALIDATE_IP, FILTER_FLAG_IPV4 )
		) {
			$the_ip = $headers['HTTP_X_FORWARDED_FOR'];
		} else {
			$the_ip = filter_var( $_SERVER['REMOTE_ADDR'], FILTER_VALIDATE_IP, FILTER_FLAG_IPV4 );
		}
		return $the_ip;
	}
}

/**
 * Plugin name for WooZonePNF_time_elapsed_string.
 *
 * @since 1.0
 * @return string
 */
if ( ! function_exists( 'WooZonePNF_time_elapsed_string' ) ) {
	function WooZonePNF_time_elapsed_string($ptime)
	{
	    $etime = time() - $ptime;
	
	    if ($etime < 1)
	    {
	        return '0 seconds';
	    }
	
	    $a = array( 365 * 24 * 60 * 60  =>  'year',
	                 30 * 24 * 60 * 60  =>  'month',
	                      24 * 60 * 60  =>  'day',
	                           60 * 60  =>  'hour',
	                                60  =>  'minute',
	                                 1  =>  'second'
	                );
	    $a_plural = array( 'year'   => 'years',
	                       'month'  => 'months',
	                       'day'    => 'days',
	                       'hour'   => 'hours',
	                       'minute' => 'minutes',
	                       'second' => 'seconds'
	                );
	
	    foreach ($a as $secs => $str)
	    {
	        $d = $etime / $secs;
	        if ($d >= 1)
	        {
	            $r = round($d);
	            return $r . ' ' . ($r > 1 ? $a_plural[$str] : $str) . ' ago';
	        }
	    }
	}
}


/**
 * Plugin name for WooZonePNF.
 *
 * @since 1.0
 * @return string
 */
function WooZonePNF_plugin_name() {
	return WooZonePNF()->pluginName();
}