<?php
/*
Plugin Name: SearchAzon - WooCommerce Amazon Affiliates Auto Search Plugin
Plugin URI: http://www.aa-team.com
Description: SearchAzon allows you to integrate the Amazon Search functionality into your Website. Automatic insertion into WooCommerce & Wordpress Search when Searched Content / Products are not found! No hassle, no coding, no amazon aws keys!
Version: 1.4.1
Author: 20script
Author URI: http://www.20script.ir
*/

// don't load directly
if ( ! defined( 'ABSPATH' ) ) {
	die( '-1' );
}
/**
 * Current WooZonePNF version
 */
if ( ! defined( 'WooZonePNF_VERSION' ) ) {
	/**
	 *
	 */
	define( 'WooZonePNF_VERSION', '1.4.1' );
}
/**
 * WooZonePNF starts here. Manager sets mode, adds required wp hooks and loads required object of structure
 *
 * Manager controls and access to all modules and classes of WooZonePNF.
 *
 * @package ' . ( $this->plugin_name ) . '
 * @since   1.0
 */
class WooZonePNF {
	/**
	 * Set status/mode for WooZonePNF.
	 *
	 * It depends on what functionality is required from WooZonePNF to work with current page/part of WP.
	 *
	 * Possible values:
	 *  none - current status is unknown, default mode;
	 *  page - simple wp page;
	 *  admin_page - wp dashboard;
	 *  admin_frontend_editor - WooZonePNF front end editor version;
	 *  admin_settings_page - settings page
	 *  page_editable - inline version for iframe in front end editor;
	 *
	 * @since 1.0
	 * @var string
	 */
	private $mode = 'none';

	/**
	 * Enables WooZonePNF to act as the theme plugin.
	 *
	 * @since 1.0
	 * @var bool
	 */

	private $is_as_theme = false;
	/**
	 * WooZonePNF is network plugin or not.
	 * @since 1.0
	 * @var bool
	 */
	private $is_network_plugin = null;

	/**
	 * List of paths.
	 *
	 * @since 1.0
	 * @var array
	 */
	private $paths = array();

	/**
	 * Set updater mode
	 * @since 1.0
	 * @var bool
	 */
	private $disable_updater = false;

	/**
	 * Modules and objects instances list
	 * @since 1.0
	 * @var array
	 */
	private $factory = array();

	/**
	 * File name for components manifest file.
	 *
	 * @since 4.4
	 * @var string
	 */
	private $components_manifest = 'components.json';

	/**
	 * @var string
	 */
	public $plugin_name = 'WooZonePNF';
    public $localizationName = 'WooZonePNF';
    public $alias = 'WooZonePNF';

	/**
	 * The keywords object
	 */
	public $autofind = null;

	/**
	 * The tmdb object
	 */
	public $config = null;

	/**
	 * The about object
	 */
	public $about = null;

	/**
	 * The products object
	 */
	public $products = null;

	/**
	 * The template_config object
	 */
	public $template_config = null;

	/**
	 * The dashboard object
	 */
	public $dashboard = null;

	/**
	 * The wp_filesystem object
	 */
	public $wp_filesystem = null;

	/**
	 * The wpbd object
	 */
	public $db = null;

	/**
	 * The template object
	 */
	public $template = null;

	public $settings = array();

	public $amz_setup = array();

	public $amz_cates = array();

	public $updater_dev = null;


	/**
	 * Constructor loads API functions, defines paths and adds required wp actions
	 *
	 * @since  1.0
	 */
	public function __construct()
	{
		if( defined('UPDATER_DEV') ) {
			$this->updater_dev = (string) UPDATER_DEV;
		}

		$dir = dirname( __FILE__ );
		$upload_dir = wp_upload_dir();

		$this->load_settings();

		/**
		 * Define path settings for WooZonePNF.
		 */
		$this->setPaths( array(
			'APP_ROOT' 				=> $dir,
			'WP_ROOT' 				=> preg_replace( '/$\//', '', ABSPATH ),
			'APP_DIR' 				=> basename( $dir ),
			'CONFIG_DIR' 			=> $dir . '/config',
			'ASSETS_DIR' 			=> $dir . '/assets',
			'ASSETS_DIR_NAME' 		=> 'assets',
			'TEMPLATES_DIR_NAME' 	=> 'templates',
			'APP_URL'  				=> plugin_dir_url( __FILE__ ),
			'TEMPLATES_URL'  		=> plugin_dir_url( __FILE__ ) . 'templates/',
			'HELPERS_DIR' 			=> $dir . '/include/helpers',
			'AUTO_FIND_DIR' 		=> $dir . '/include/auto-find',
			'DASHBOARD_DIR' 		=> $dir . '/include/dashboard',
			'ABOUT_DIR' 			=> $dir . '/include/about',
			'CONFIG_DIR' 			=> $dir . '/include/config',
			'TEMPLATE_CONFIG_DIR' 	=> $dir . '/include/template',
			'PRODUCTS_DIR' 			=> $dir . '/include/products',
			'PRODUCTS_URL' 			=> plugin_dir_url( __FILE__ ) . 'include/products/',
			'SEARCH_DIR' 			=> $dir . '/include/search',
			'INCLUDE_DIR' 			=> $dir . '/include',
			'TEMPLATES_DIR' 		=> $dir . '/templates',
			'INCLUDE_DIR_NAME' 		=> 'include',
			'PARAMS_DIR' 			=> $dir . '/include/params',
			'VENDORS_DIR' 			=> $dir . '/include/classes/vendors',
			'UPLOAD_BASE_DIR'  		=> $upload_dir['basedir'],
			'UPLOAD_BASE_URL'  		=> $upload_dir['baseurl'],
		) );

		// Load API
		require_once $this->path( 'HELPERS_DIR', 'helpers.php' );
		require_once $this->path( 'HELPERS_DIR', 'social.class.php' );
		require_once $this->path( 'HELPERS_DIR', 'settings.class.php' );

		require_once $this->path( 'HELPERS_DIR', 'template.class.php' );
		$this->template = new WooZonePNF_Template( $this );

		// Add hooks
		add_action( 'plugins_loaded', array( &$this, 'pluginsLoaded' ), 9 );
		add_action( 'init', array( &$this, 'init' ), 9 );

		// load WP_Filesystem
		include_once ABSPATH . 'wp-admin/includes/file.php';
	   	WP_Filesystem();
		global $wp_filesystem;
		$this->wp_filesystem = $wp_filesystem;

		register_activation_hook( __FILE__, array( $this, 'install' ) );

		// create AJAX request
		add_action('wp_ajax_WooZonePNF_register', array(
            $this,
            'ajax_register'
        ));

        add_action( 'init', array($this, 'init_session') );

        add_action( 'wp_ajax_WooZonePNF_action', array( $this, 'ajax_request' ) );
        add_action( 'wp_ajax_nopriv_WooZonePNF_action', array( $this, 'ajax_request' ) );

        // trigger the ajax for frontend
		add_action('wp_ajax_wooWooZonePNFFrontendAjax', array( &$this, 'frontend_ajax' ));
		add_action('wp_ajax_nopriv_wooWooZonePNFFrontendAjax', array( &$this, 'frontend_ajax' ));

		// product updater
		add_action( 'admin_init', array($this, 'product_updater') );
	}

	/**
	 * Gets updater instance.
	 *
	 * @return AATeam_Product_Updater
	 */
	public function product_updater()
	{
		require_once( $this->path( 'ASSETS_DIR', 'class-updater.php' ) );

		if( class_exists('SearchAzon_AATeam_Product_Updater') ){
			$product_data = get_plugin_data( $this->path( 'APP_ROOT', 'plugin.php' ), false );
			new SearchAzon_AATeam_Product_Updater( $this, $product_data['Version'], 'searchazon', 'searchazon/plugin.php' );
		}
	}

	public function load_settings()
	{
		$this->settings['id'] = $this->get_campaign_id();
		$this->settings['setup'] = get_option( 'WooZonePNF_Plugin_Settings_' . $this->get_campaign_id(), true );
		$this->settings['template'] = get_option( 'WooZonePNF_Template_Settings_' . $this->get_campaign_id(), true );
	}

	public function get_products_frontent()
	{
		$this->settings['boxes'] = get_option( 'WooZonePNF_' . ( $this->get_campaign_id() ) . '_products', true );
	}

	/**
	 * Callback function WP plugin_loaded action hook. Loads locale
	 *
	 * @since  1.0
	 * @access public
	 */
	public function pluginsLoaded()
	{
		// Setup locale
		do_action( 'WooZonePNF_plugins_loaded' );
		load_plugin_textdomain( 'WooZonePNF', false, dirname( plugin_basename( __FILE__ ) ) . '/languages/' );
	}

	public function init_session()
	{
		// we'll skip session init if on site health page
		$is_site_health = false;
		if (
			( isset($_SERVER['REQUEST_URI']) && strpos( $_SERVER['REQUEST_URI'], 'site-health.php') )
			|| ( isset($_SERVER['HTTP_REFERER']) && strpos( $_SERVER['HTTP_REFERER'], 'site-health.php') )
			|| ( isset($_SERVER['HTTP_REFERER']) && strpos( $_SERVER['HTTP_REFERER'], 'theme-editor.php') )
			|| ( isset($_SERVER['HTTP_REFERER']) && strpos( $_SERVER['HTTP_REFERER'], 'plugin-editor.php') )
		) {
			$is_site_health = true;
		}

		if( !$is_site_health && !session_id() ) {
	        session_start();
	    }
	}

	/**
	 * Callback function for WP init action hook. Sets WooZonePNF mode and loads required objects.
	 *
	 * @since  1.0
	 * @access public
	 *
	 * @return void
	 */
	public function init()
	{
		do_action( 'WooZonePNF_before_init' );

        $this->update_developer();

		global $wpdb;
		$this->db = $wpdb;

		// Set current mode
		$this->setMode();

		// Load the admin menu hook
		$this->adminInterface();

		/**
		 * if is admin and not frontend.
		 */
		if( $this->mode === 'admin' ) {

            // If the user can manage options, let the fun begin!
            if ( current_user_can( 'manage_options' ) ) {
                // Adds actions to hook in the required css and javascript
                add_action( "admin_print_styles", array( &$this, 'admin_load_styles') );
                add_action( "admin_print_scripts", array( &$this, 'admin_load_scripts') );
            }

			// redirect on install to settings page
			$redirect_url = get_option( 'WooZonePNF_redirect_to' );
			if( $redirect_url ){
				delete_option( 'WooZonePNF_redirect_to' );
				wp_redirect( $redirect_url, 301 ); exit;
			}

			// load config interface
			require_once $this->path( 'CONFIG_DIR', 'config.class.php' );
			$this->config = new WooZonePNF_config( $this );

			// load products interface
			require_once $this->path( 'PRODUCTS_DIR', 'products.class.php' );
			$this->products = new WooZonePNF_products( $this );

			// load about interface
			require_once $this->path( 'ABOUT_DIR', 'about.class.php' );
			$this->about = new WooZonePNF_about( $this );

			// load about interface
			require_once $this->path( 'DASHBOARD_DIR', 'dashboard.class.php' );
			$this->dashboard = new WooZonePNF_dashboard( $this );

			// add new field into woocommerce product page
			add_action( 'woocommerce_product_options_pricing', array( &$this, 'discount_price_field') );
			//add_action( 'save_post', array( &$this, 'black_friday_price_save_field' ) );

		}else{
		}

		$this->load_custom_post_types();

		do_action( 'WooZonePNF_after_init' );
	}


	private function load_custom_post_types()
	{
		foreach( glob( $this->path( 'APP_ROOT', "/post-types/*/init.class.php" ) ) as $pt_init ){
			$this->cfg['CURRENT_PT_PATH'] = $pt_init;
			$this->cfg['CURRENT_PT_URL'] = plugin_dir_url( $this->cfg['CURRENT_PT_PATH'] );

			$GLOBALS['WooZonePNF'] = $this;
			require_once $pt_init;
		}
	}

	public function install()
	{
		global $wpdb;

		// install db
		// check if table exist, if not create table
		$table_name = $wpdb->prefix . "WooZonePNF_stats";
		if ($wpdb->get_var( "show tables like '$table_name'" ) != $table_name) {

			$sql = "
				CREATE TABLE IF NOT EXISTS " . $table_name . " (
				  	`id` INT(10) NOT NULL AUTO_INCREMENT,
					`action` VARCHAR(150) NOT NULL DEFAULT '',
					`keyword` VARCHAR(150) NOT NULL DEFAULT '',
					`ip` VARCHAR(50) NOT NULL DEFAULT '',
					`country` VARCHAR(150) NOT NULL DEFAULT '',
					`amazon_site` VARCHAR(150) NOT NULL DEFAULT '',
					`url` VARCHAR(150) NOT NULL DEFAULT '',
					`date` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
					PRIMARY KEY (`id`)
				);
				";

			require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
			dbDelta($sql);
		}

		$options = get_option( 'WooZonePNF_Plugin_Settings_aa' );

		if( !$options && !is_array($options) ){
			$file = $this->path( 'ASSETS_DIR', 'default.json' );
			$default = json_decode( $this->wp_filesystem->get_contents( $file ), true);
			add_option( 'WooZonePNF_Plugin_Settings_aa', $default );

		}
	}

    public function update_developer()
    {
        //return true;
        if ( in_array($_SERVER['REMOTE_ADDR'], array('86.124.69.217', '86.124.76.250')) ) {
            $this->dev = 'andrei';
        } else {
            $this->dev = 'gimi';
        }
    }

	/**
	 * Load required logic for operating in Wp Admin dashboard.
	 *
	 * @since  1.0
	 * @access protected
	 *
	 * @return void
	 */
	public function adminInterface()
	{
		// Settings page. Adds menu page in admin panel.
		$this->addMenuPageHooks();

	}

	public function addMenuPageHooks()
	{
		if ( current_user_can( 'manage_options' ) ) {
			add_action( 'admin_menu', array( &$this, 'addMenuPage' ) );
		}
	}

	public function addMenuPage()
	{
		$page = add_menu_page( esc_html__( 'SearchAzon', 'WooZonePNF' ),
			__( "SearchAzon" ),
			'manage_options',
			'WooZonePNF',
			array( &$this, 'render' ),
			WooZonePNF_asset_url( 'images/icon.png' )
		);

		if ( isset( $_GET['page'] ) && $_GET['page'] == 'WooZonePNF' )  {
			add_action( "admin_print_styles", array( &$this, 'adminLoad' ) );
			add_action( "admin_head", array( &$this, 'adminLoadScript' ) );
		}
	}

	/**
	 * Set up the enqueue for the CSS & JavaScript files.
	 *
	 */
	public function adminLoad()
	{
		wp_enqueue_style( 'WooZonePNF-core', WooZonePNF_asset_url( 'style.css' ), array(), WooZonePNF_VERSION );
		wp_enqueue_style( 'WooZonePNF-settings', WooZonePNF_asset_url( 'settings.css' ), array(), WooZonePNF_VERSION );


		wp_enqueue_style( 'WooZonePNF-timepicker-addon', WooZonePNF_asset_url( 'jquery-ui-timepicker-addon.css' ), array(), '4.3.0' );
		wp_enqueue_style( 'WooZonePNF-font-awesome', WooZonePNF_asset_url( 'font-awesome.min.css' ), array(), '4.3.0' );

		wp_enqueue_script( 'WooZonePNF-script', WooZonePNF_asset_url( 'admin.js' ), array(), '1.0.0' );
		wp_enqueue_script( 'WooZonePNF-gstatic-charts', 'https://www.gstatic.com/charts/loader.js', array() );
		wp_enqueue_style( 'wp-color-picker');
		wp_enqueue_script( 'wp-color-picker');
		//wp_enqueue_script( 'wp-color-picker-alpha', WooZonePNF_asset_url( 'wp-color-picker-alpha/wp-color-picker-alpha.js' ), array( 'wp-color-picker' ), '1.2.2' );
	}

	public function adminLoadScript()
	{
		wp_enqueue_script( 'WooZonePNF-timepicker-addon', WooZonePNF_asset_url( 'jquery-ui-timepicker-addon.js' ), array('jquery-ui-datepicker'), '1.0.0' );
		wp_enqueue_script( 'jquery-ui-datepicker' );
		wp_enqueue_script( 'jquery-ui-draggable' );
		wp_enqueue_script( 'jquery-ui-sortable' );
		wp_enqueue_script( 'jquery-ui-droppable' );
		wp_enqueue_script( 'jquery-ui-slider' );
		wp_enqueue_script( 'jquery-ui-dialog' );
    	wp_enqueue_style( 'jquery-style', 'http://ajax.googleapis.com/ajax/libs/jqueryui/1.8.2/themes/smoothness/jquery-ui.css' );
	}


	private function output_menu_section( $menu_arr=array() )
	{
		$html = array();
		if( count($menu_arr) > 0 ){

			$app_root = admin_url( 'admin.php?page=WooZonePNF' );
			foreach ($menu_arr as $menu_key => $value) {

				$campaign_id = WooZonePNF()->get_campaign_id();
				$html[] = '<div class="WooZonePNF_iw-menu-section ' . ( $campaign_id == $menu_key ? 'menu_is_open' : '' ) . '">';


				if( count($value['links']) > 0 ){
					foreach ($value['links'] as $link_key => $link_value) {
						$link_value['url'] = str_replace( '%app_root%', $app_root, $link_value['url'] );
						//' . ( WooZonePNF_action() == $link_key ? 'class="on"' : '' ) . '

						$selected = "";
						if( WooZonePNF_action() == $link_key && $campaign_id == $menu_key ){
							$selected = 'on';
						}
						$html[] = '<a href="' . ( $link_value['url'] ) . '" class="' . ( $selected ) . '"><i class="fa ' . ( $link_value['icon'] ) . '"></i> ' . ( ucfirst( $link_value['label'] ) ) . '</a>';

						if( isset($link_value['submenu']) && count($link_value['submenu']) > 0 ){
							foreach ($link_value['submenu'] as $submenu_key => $submenu_value) {
								$submenu_value['url'] = str_replace( '%app_root%', $app_root, $submenu_value['url'] );

								$selected = "";
								if( WooZonePNF_action() == $submenu_key && $campaign_id == $menu_key ){
									$selected = 'on';
								}
								$html[] = '<a href="' . ( $submenu_value['url'] ) . '" class="WooZonePNF-submenu ' . ( $selected ) . '"><i class="fa fa-long-arrow-right"></i> ' . ( ucfirst( $submenu_value['label'] ) ) . '</a>';
							}
						}
					}

				}
				$html[] = '';
				$html[] = '</div>';
			}
		}

		return implode( "\n", $html );
	}

	public function has_campaigns( $array=array() )
	{
		if( $array && is_array($array) && count($array) ){
			return true;
		}

		return false;
	}

	/**
	 * Create Render points.
	 *
	 * Loaded interface depends on which page is requested by client from server and request parameters like WooZonePNF_action.
	 *
	 * @since  1.0
	 * @access protected
	 *
	 * @return void
	 */
	public function render()
	{
		$campaigns = $this->get_all_campaigns();
		$html = array();

		$html[] = '<div class="WooZonePNF_iw">';
		$html[] = '<div class="WooZonePNF_iw-loader" style="display: block;"><ul class="WooZonePNF_iw-preloader"><li></li><li></li><li></li><li></li><li></li></ul><span></span></div>';

		$html[] = 	'<div class="WooZonePNF-no-campaigns-wrapper" style="display: none;">';
		$html[] = 		'<div class="WooZonePNF-no-campaigns-content">';
		$html[] = 			'<h2>Add new campaign</h2>';
		$html[] = 			'<p>In order to use <strong>' . ( $this->plugin_name ) . '</strong> you need to create your first Campaign.</p>';
		$html[] = 			'<label>';
		$html[] = 				'<span>Campaign name:</span>';
		$html[] = 				'<input type="text" name="WooZonePNF-campaign-name">';
		$html[] = 			'</label>';
		$html[] = 			'<a id="WooZonePNF_iw-add-new-campaign" class="WooZonePNF-button yellow" href="#">Add campaign</a>';
		$html[] = 		'</div>';
		$html[] = 	'</div>';

		$html[] = '<aside>';
		$html[] = 	'<a id="WooZonePNF_iw-logo" href="' . ( admin_url( 'admin.php?page=WooZonePNF' ) ) . '"><img src="' . ( WooZonePNF_asset_url('images/aa-logo.png') ) . '" /></a>';

		$extra_menu = array();

		$extra_menu[] = array(
			'label' 	=> '',
			'links'		=> array(
				'dashboard' => array(
					'url' 	=> '%app_root%&WooZonePNF_action=dashboard',
					'label'	=> 'Dashboard',
					'icon'	=> 'fa-tachometer'
				),

				'config' => array(
					'url' 	=> '%app_root%&WooZonePNF_action=config',
					'label'	=> 'Configuration',
					'icon'	=> 'fa-cog'
				),

				'about' => array(
					'url' 	=> '%app_root%&WooZonePNF_action=about',
					'label'	=> 'About',
					'icon'	=> 'fa-question'
				)
			)
		);


		$html[] = 	$this->output_menu_section($extra_menu);


		$html[] = '<span id="WooZonePNF-version">Version: ' . ( WooZonePNF_VERSION ) . ' by <a href="http://www.aa-team.com">AA-Team</a></span>';

		$html[] = '</aside>';

		$html[] = '<section>';

		if( WooZonePNF_action() == 'config' ){

			$html[] = 	'
				<div class="WooZonePNF_iw-header">
					<h3>Configuration</h3>
				</div>';

			//$html[] = $this->print_campaigns_settings();
			$html[] = $this->config->print_interface();
		}

		else if( WooZonePNF_action() == 'about' ){
			$html[] = 	'
				<div class="WooZonePNF_iw-header">
					<h3>About</h3>
				</div>';

			$html[] = $this->about->print_interface();
		}

		else if( WooZonePNF_action() == 'dashboard' ){
			$html[] = 	'
				<div class="WooZonePNF_iw-header">
					<h3>Dashboard</h3>
				</div>';

			//$html[] = $this->print_campaigns_settings();
			$html[] = $this->dashboard->print_interface();
		}

		$html[] = '</section>';

		$html[] = '</div>';


		echo implode( "\n", $html );
	}

	public function get_campaign_id()
	{
		return 'aa';
	}

	public function get_campaign_name()
	{
		$campaign_id = $this->get_campaign_id();
		if( $campaign_id != "" ){
			$campaigns = $this->get_all_campaigns();

			if( isset($campaigns[$campaign_id]) ){
				return $campaigns[$campaign_id];
			}
		}

		return '';
	}

	public function plugin_urls( $section='', $campaign_id='' )
	{
		$base_url = admin_url( '?page=WooZonePNF&WooZonePNF_action=' . $section );

		if( $campaign_id != "default" && $campaign_id != "" ){
			$base_url .= '&campaign_id=' . $campaign_id;
		}

		return $base_url;
	}

	public function print_campaigns_settings()
	{
		$html = array();
		$html[] = '<div id="WooZonePNF_iw-section-content">';
		$html[] = 	'<div class="WooZonePNF-campaigns-selector">';
		$html[] = 		'<div class="WooZonePNF-campaigns-wrapper">';
		$html[] = 			'<div class="WooZonePNF-campaigns-left">';
		$html[] = 				'<div class="WooZonePNF-campaigns-left-wrapper">';

		$options = get_option( $this->alias . "_campaigns", true );
		if( $options && is_array($options) && count($options) > 0 ){
			foreach ($options as $key => $value) {
				$html[] = '<div data-id="' . ( $key ) . '" class="WooZonePNF-campaign-item ' . ( $this->get_campaign_id() == $key ? 'WooZonePNF-campaigns-on' : '' ) . '">';
				$html[] = 	'<span class="WooZonePNF-campaign-headline">' . $value . '</span>';
				$html[] = 	'<ul class="WooZonePNF-campaign-item-menu">';
				$html[] = 		'<li><a href="' . ( $this->plugin_urls( 'dashboard', $key ) ) . '">Dashboard</a></li>';
				$html[] = 		'<li>';
				$html[] = 			'<a href="#">Setup</a>';
				$html[] = 			'<ul>';
				$html[] = 				'<li><a href="' . ( $this->plugin_urls( 'config', $key ) ) . '">Page Setup</a></li>';
				$html[] = 				'<li><a href="' . ( $this->plugin_urls( 'template_config', $key ) ) . '">Template Setup</a></li>';
				$html[] = 				'<li><a href="' . ( $this->plugin_urls( 'products', $key ) ) . '">Products Setup</a></li>';
				$html[] = 			'</ul>';
				$html[] = 		'</li>';
				$html[] = 		'<li>';
				$html[] = 			'<a href="#">Preview</a>';
				$html[] = 			'<ul>';
				$html[] = 				'<li><a href="' . ( home_url( '?' . ( WooZonePNF()->alias ) . '_page=countdown&campaign_id=' . $key . '&key=' . WooZonePNF()->preview_key('countdown') ) ) . '" target="_blank">Countdown</a></li>';
				$html[] = 				'<li><a href="' . ( home_url( '?' . ( WooZonePNF()->alias ) . '_page=products&campaign_id=' . $key . '&key=' . WooZonePNF()->preview_key('products') ) ) . '" target="blank">Products</a></li>';
				$html[] = 			'</ul>';
				$html[] = 		'</li>';
				$html[] = 		'<li><a href="#" class="WooZonePNF-campaign-delete">Delete campaign</a></li>';
				$html[] = 	'</ul>';
				$html[] = '</div>';

			}
		}
		$html[] = 				'<input type="hidden" id="WooZonePNF-campaign_id" value="' . ( $this->get_campaign_id() ) . '" />';
		$html[] = 				'</div>';
		$html[] = 			'</div>';
		$html[] = 			'<div class="WooZonePNF-campaigns-btn">';
		$html[] = 				'<a href="#" class="WooZonePNF-campaigns-btn-add-new">Add new campaign</a>';
		$html[] = 				'<div class="WooZonePNF-campaigns-add-new-box">';
		$html[] = 					'<h2>Add new template</h2>';
		$html[] = 					'<input type="text" name="WooZonePNF-campaigns-name" />';
		$html[] = 					'<span>Your new template name</span>';
		$html[] = 					'<a href="#" target="blank" style="height: 40px; line-height: 40px" class="WooZonePNF-create-campaign-btn ' . ( WooZonePNF()->alias ) . '-button red">ADD NEW</a>';
		$html[] = 				'</div>';
		$html[] = 			'</div>';
		$html[] = 		'</div>';
		$html[] = 	'</div>';
		$html[] = '</div>';

		return implode( "\n", $html );
	}

	/**
	 * Print WooZonePNF interface
	 *
	*/
	public function print_interface()
	{
		$html = array();

	}

	/**
	 * Set WooZonePNF mode.
	 *
	 * Mode depends on which page is requested by client from server and request parameters like WooZonePNF_action.
	 *
	 * @since  1.0
	 * @access protected
	 *
	 * @return void
	 */
	protected function setMode()
	{
		if ( is_admin() ) {
			$this->mode = 'admin';
		} else {
			$this->mode = 'frontend';
		}
	}

	/**
	 * Sets version of the WooZonePNF in DB as option `WooZonePNF_VERSION`
	 *
	 * @since 1.0
	 * @access protected
	 *
	 * @return void
	 */
	protected function setVersion()
	{
		$version = get_option( 'WooZonePNF_VERSION' );
		if ( ! is_string( $version ) || version_compare( $version, WooZonePNF_VERSION ) !== 0 ) {
			add_action( 'WooZonePNF_after_init', array( WooZonePNF_settings(), 'rebuild' ) );
			update_option( 'WooZonePNF_VERSION', WooZonePNF_VERSION );
		}
	}

	/**
	 * Get current mode for WooZonePNF.
	 *
	 * @since  1.0
	 * @access public
	 *
	 * @return string
	 */
	public function mode() {
		return $this->mode;
	}

	/**
	 * Setter for paths
	 *
	 * @since  1.0
	 * @access protected
	 *
	 * @param $paths
	 */
	protected function setPaths( $paths ) {
		$this->paths = $paths;
	}

	/**
	 * Gets absolute path for file/directory in filesystem.
	 *
	 * @since  1.0
	 * @access public
	 *
	 * @param $name - name of path dir
	 * @param string $file - file name or directory inside path
	 *
	 * @return string
	 */
	public function path( $name, $file = '' ) {
		$path = $this->paths[ $name ] . ( strlen( $file ) > 0 ? '/' . preg_replace( '/^\//', '', $file ) : '' );

		return apply_filters( 'WooZonePNF_path_filter', $path );
	}

	/**
	 * Set default post types. WooZonePNF editors are enabled for such kind of posts.
	 *
	 * @param array $type - list of default post types.
	 */
	public function setEditorDefaultPostTypes( array $type ) {
		$this->editor_default_post_types = $type;
	}

	/**
	 * Returns list of default post types where user can use WooZonePNF editors.
	 *
	 * @since  1.0
	 * @access public
	 *
	 * @return array
	 */
	public function editorDefaultPostTypes() {
		return $this->editor_default_post_types;
	}

	/**
	 * Get post types where WooZonePNF editors are enabled.
	 *
	 * @since  1.0
	 * @access public
	 *
	 * @return array
	 */
	public function editorPostTypes()
	{
		if ( ! isset( $this->editor_post_types ) ) {
			$pt_array = WooZonePNF_settings()->get( 'content_types' );
			$this->editor_post_types = $pt_array ? $pt_array : $this->editorDefaultPostTypes();
		}

		return $this->editor_post_types;
	}

	/**
	 * Setter for as network plugin for MultiWP.
	 *
	 * @since  1.0
	 * @access public
	 *
	 * @param bool $value
	 */
	public function setAsNetworkPlugin( $value = true )
	{
		$this->is_network_plugin = $value;
	}

	/**
	 * Directory name where template files will be stored.
	 *
	 * @since  1.0
	 * @access public
	 *
	 * @return string
	 */
	public function uploadDir()
	{
		return 'aa-backup-manager';
	}

	/**
	 * Getter for plugin name variable.
	 * @since 1.0
	 *
	 * @return string
	 */
	public function pluginName()
	{
		return $this->plugin_name;
	}

	/**
	 * Get absolute url for WooZonePNF asset file.
	 *
	 * Assets are css, javascript, less files and images.
	 *
	 * @since 4.2
	 *
	 * @param $file
	 *
	 * @return string
	 */
	public function includeUrl( $file )
	{
		return preg_replace( '/\s/', '%20', plugins_url( $this->path( 'INCLUDE_DIR_NAME', $file ), __FILE__  ) );
	}

	/**
	 * Get absolute url for WooZonePNF asset file.
	 *
	 * Assets are css, javascript, less files and images.
	 *
	 * @since 4.2
	 *
	 * @param $file
	 *
	 * @return string
	 */
	public function assetUrl( $file )
	{
		return preg_replace( '/\s/', '%20', plugins_url( $this->path( 'ASSETS_DIR_NAME', $file ), __FILE__ ) );
	}

	/**
	 * Get absolute url for WooZonePNF asset file.
	 *
	 * Assets are css, javascript, less files and images.
	 *
	 * @since 4.2
	 *
	 * @param $file
	 *
	 * @return string
	 */
	public function templatesUrl( $file )
	{
		return preg_replace( '/\s/', '%20', plugins_url( $this->path( 'TEMPLATES_DIR_NAME', $file ), __FILE__ ) );
	}

	public function mb_unserialize($serial_str)
	{
        static $adds_slashes = -1;
        if ($adds_slashes === -1) // Check if preg replace adds slashes
            $adds_slashes = (false !== strpos( preg_replace('!s:(\d+):"(.*?)";!se', "'s:'.strlen('$2').':\"$2\";'", 's:1:""";'), '\"' ));

        $result = @unserialize( preg_replace('!s:(\d+):"(.*?)";!se', "'s:'.strlen('$2').':\"$2\";'", $serial_str) );
        return ( $adds_slashes ? stripslashes_deep( $result ) : $result );
    }

	public function print_filters_for( $hook = '' )
	{
	    global $wp_filter;
	    if( empty( $hook ) || !isset( $wp_filter[$hook] ) )
	        return;
	}


    public function admin_load_styles()
    {
        // admin notices - css styles
        wp_enqueue_style( 'WooZonePNF-admin-notices-style', WooZonePNF_asset_url( 'admin_notices.css' ), array(), WooZonePNF_VERSION );
    }

    public function admin_load_scripts() {
    	wp_enqueue_media();
    }

    public function prepareForInList($v) {
        return "'".$v."'";
    }

    public function template_path()
    {
    	 return apply_filters( 'WooZonePNF_template_path', 'templates/' );
    }

	public function get_pages()
	{
		$_pages = array();
		$pages = get_pages();
		if( $pages && count($pages) > 0 ){
	  		foreach ( $pages as $page ) {
	  			$_pages[$page->ID] = $page->post_title;
	  		}
	  	}

	  	return $_pages;
	}

	public function ajax_register()
	{
		parse_str( $_REQUEST['params'], $params );

		$ipc = isset($params['WooZonePNF_iw-validation-token']) ? $params['WooZonePNF_iw-validation-token'] : '';
		$email = isset($params['WooZonePNF_iw-validation-email']) ? $params['WooZonePNF_iw-validation-email'] : '';

		$link = "http://cc.aa-team.com/validation/validate.php?ipc=%s&email=%s&app=" . $this->alias;
		$aa_server_response = wp_remote_retrieve_body( wp_remote_get( sprintf( $link, $ipc,$email, $email ) ) );
		if( $aa_server_response ){
			$aa_server_response = json_decode( $aa_server_response, true );
			if( $aa_server_response ){

				if( $aa_server_response['status'] == 'valid' ){
					if( isset($aa_server_response['html']) ){
						update_option( "_" . $this->alias . "_register_html", $aa_server_response['html'] );

						die( json_encode( array( 'status' => 'valid' ) ));
					}
				}
			}
		}
	}

	public function getAllGfonts( $what='all' )
	{
		$file = $this->path( 'ASSETS_DIR', 'fonts/google-webfonts.json' );
		$fonts = json_decode( $this->wp_filesystem->get_contents( $file ), true);

		$ret_fonts = array();
		$ret_fonts['system'] = 'Arial';
		$ret_fonts['system'] = 'Arial Black';
		$ret_fonts['system'] = 'Impact';
		$ret_fonts['system'] = 'Verdana';
		if(count($fonts) > 0 ){
			foreach ( $fonts as $font ) {
				$ret_fonts[$font] = $font;
			}
		}

		if( $what == 'all' ){
			return $ret_fonts;
		}
	}

	public function get_install_site_name()
	{
		$url = home_url();
		$parse = parse_url($url);

		return $parse['host'];
	}

	public function do_range( $arr )
	{
		$newarr = array();
		if ( is_array($arr) && count($arr)>0 ) {
			foreach ($arr as $k => $v) {
				$newarr[ $v ] = $v;
			}
		}
		return $newarr;
	}

	public function preview_key( $section='' )
	{
		$campaign_id = $this->get_campaign_id();

		// generate and store a new key
		$key = uniqid() . rand(0, 1000);
		$db_key = get_option( $section . '_'  . ( $campaign_id ) . '_preview_key', true );
		if( $db_key !== true && trim($db_key) != "" ){
			$key = $db_key;
		}else{
			update_option( $section . '_'  . ( $campaign_id ) . '_preview_key', $key );
		}

		return $key;
	}

	public function frontend_ajax()
	{
		$action = isset($_REQUEST['sub_action']) ? $_REQUEST['sub_action'] : '';
		if ( $action == 'getCurrentServerTime' ) {

			$current_timezone = date_default_timezone_get(); //change current timezone
			$timezone = isset($_REQUEST['timezone']) ? $_REQUEST['timezone'] : $current_timezone;

			date_default_timezone_set( $timezone );

			// Counting down to
			$countdown_to = trim($_REQUEST['countto']); // 24-Hour Format: YYYY-MM-DD HH:MM:SS"

			// Getting the current time
			$count_from = date("Y-m-d H:i:s"); // current time -- NO NEED TO CHANGE

			// getting Date difference in SECONDS
			$diff = array(
				'seconds' => $this->datediff("s", $count_from, $countdown_to, true),
				'minutes' => $this->datediff("n", $count_from, $countdown_to, true),
				'hours'   => $this->datediff("h", $count_from, $countdown_to, true),
				'days'    => $this->datediff("d", $count_from, $countdown_to, true)
			);

			$countDown = array(
				'seconds' => $diff['seconds'] % 60,
				'mins'	  => floor($diff['seconds']/60)%60,
				'hours'	  => floor($diff['seconds']/60/60)%24,
				'days'	  => floor($diff['seconds']/60/60/24),
			    'months'	=> floor($diff['seconds']/60/60/24/7/4),
			    'weeks'	  => floor($diff['seconds']/60/60/24/7)
			);

			date_default_timezone_set( $current_timezone ); //restore default timezone

			header('Content-Type: text/json');
			die( json_encode($countDown) );

		}
		else if ( $action == 'saveSubscriber' ) {
			$r = array(
				'campaign' => ( isset($_REQUEST['campaign']) && !empty($_REQUEST['campaign']) ? trim($_REQUEST['campaign']) : '' ),
				'name' => ( isset($_REQUEST['name']) && !empty($_REQUEST['name']) ? trim($_REQUEST['name']) : '' ),
				'email' => ( isset($_REQUEST['email']) && !empty($_REQUEST['email']) ? trim($_REQUEST['email']) : '' )
			);

			if ( $r['name']!='' && $r['email']!='' ) {
				$table_name = $this->db->prefix . 'WooZonePNF_subs';

				// save in db!
				$this->db->insert(
					$table_name,
					array(
						'campaign' => esc_sql( $r['campaign'] ),
						'email' => esc_sql( $r['email'] ),
						'name'	=> esc_sql( $r['name'] )
					),
					array(
						"%s",
						"%s"
					)
				);

				$id = $this->db->insert_id;

				die(json_encode(array(
					'status' => 'valid',
					'data' => ''
				)));
			}
			die(json_encode(array(
				'status' => 'invalid',
				'data' => ''
			)));
		}
	}

	// Date difference function. Will be using below
	private function datediff($interval, $datefrom, $dateto, $using_timestamps = false) {
		/*
		$interval can be:
		yyyy - Number of full years
		q - Number of full quarters
		m - Number of full months
		y - Difference between day numbers
		(eg 1st Jan 2004 is "1", the first day. 2nd Feb 2003 is "33". The datediff is "-32".)
		d - Number of full days
		w - Number of full weekdays
		ww - Number of full weeks
		h - Number of full hours
		n - Number of full minutes
		s - Number of full seconds (default)
		*/

		if (!$using_timestamps) {
			$datefrom = strtotime($datefrom, 0);
			$dateto = strtotime($dateto, 0);
		} else {
			$datefrom = strtotime($datefrom);
			$dateto = strtotime($dateto);
		}
		$difference = $dateto - $datefrom; // Difference in seconds

		switch($interval) {

			case 'yyyy': // Number of full years

			$years_difference = floor($difference / 31536000);
			if (mktime(date("H", $datefrom), date("i", $datefrom), date("s", $datefrom), date("n", $datefrom), date("j", $datefrom), date("Y", $datefrom)+$years_difference) > $dateto) {
				$years_difference--;
			}
			if (mktime(date("H", $dateto), date("i", $dateto), date("s", $dateto), date("n", $dateto), date("j", $dateto), date("Y", $dateto)-($years_difference+1)) > $datefrom) {
				$years_difference++;
			}
			$datediff = $years_difference;
			break;

			case "q": // Number of full quarters

			$quarters_difference = floor($difference / 8035200);
			while (mktime(date("H", $datefrom), date("i", $datefrom), date("s", $datefrom), date("n", $datefrom)+($quarters_difference*3), date("j", $dateto), date("Y", $datefrom)) < $dateto) {
				$months_difference++;
			}
			$quarters_difference--;
			$datediff = $quarters_difference;
			break;

			case "m": // Number of full months

			$months_difference = floor($difference / 2678400);
			while (mktime(date("H", $datefrom), date("i", $datefrom), date("s", $datefrom), date("n", $datefrom)+($months_difference), date("j", $dateto), date("Y", $datefrom)) < $dateto) {
				$months_difference++;
			}
			$months_difference--;
			$datediff = $months_difference;
			break;

			case 'y': // Difference between day numbers

			$datediff = date("z", $dateto) - date("z", $datefrom);
			break;

			case "d": // Number of full days

			$datediff = floor($difference / 86400);
			break;

			case "w": // Number of full weekdays

			$days_difference = floor($difference / 86400);
			$weeks_difference = floor($days_difference / 7); // Complete weeks
			$first_day = date("w", $datefrom);
			$days_remainder = floor($days_difference % 7);
			$odd_days = $first_day + $days_remainder; // Do we have a Saturday or Sunday in the remainder?
			if ($odd_days > 7) { // Sunday
				$days_remainder--;
			}
			if ($odd_days > 6) { // Saturday
				$days_remainder--;
			}
			$datediff = ($weeks_difference * 5) + $days_remainder;
			break;

			case "ww": // Number of full weeks

			$datediff = floor($difference / 604800);
			break;

			case "h": // Number of full hours

			$datediff = floor($difference / 3600);
			break;

			case "n": // Number of full minutes

			$datediff = floor($difference / 60);
			break;

			default: // Number of full seconds (default)

			$datediff = $difference;
			break;
		}

		return $datediff;
	}

	public function woocommerce_install()
	{
		if ( in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) ) {
		    return true;
		}

		return false;
	}

	public function create_zip($files = array(), $destination = '', $overwrite = false, $basename="")
	{
        if(file_exists($destination) && !$overwrite) {
            return false;
        }
        $valid_files = array();
        if(is_array($files)) {
            foreach($files as $file) {
                if(file_exists( $basename . '/' . $file)) {
                    $valid_files[] = $file;
                }
            }
        }
        if(count($valid_files)) {
            $zip = new ZipArchive();
            if($zip->open($destination,$overwrite ? ZIPARCHIVE::OVERWRITE : ZIPARCHIVE::CREATE) !== true) {
                return false;
            }
            foreach($valid_files as $file) {
                $zip->addFile( $basename . '/' . $file, $file );
            }
            $zip->close();
            return file_exists($destination);
        } else {
            return false;
        }
    }

    public static function deleteDir($dirPath)
    {
	    if (! is_dir($dirPath)) {
	        throw new InvalidArgumentException("$dirPath must be a directory");
	    }
	    if (substr($dirPath, strlen($dirPath) - 1, 1) != '/') {
	        $dirPath .= '/';
	    }
	    $files = glob($dirPath . '*', GLOB_MARK);
	    foreach ($files as $file) {
	        if (is_dir($file)) {
	            self::deleteDir($file);
	        } else {
	            unlink($file);
	        }
	    }
	    rmdir($dirPath);
	}

	private function rebuild_attachament( $file_path='' )
	{
		$uploads = wp_upload_dir();
		$uploads_path = $uploads['path'] . '';
		$uploads_url = $uploads['url'];
		$filename = basename( $file_path );

		$image = WooZonePNF()->wp_filesystem->get_contents( $file_path );

		//write image if the wp method fails
		$has_wrote = WooZonePNF()->wp_filesystem->put_contents(
			$uploads_path . '/' . $filename, $image, FS_CHMOD_FILE
		);

		if( !$has_wrote ){
			file_put_contents( $uploads_path . '/' . $filename, $image );
		}

		// Add image in the media library - Step 3
		$wp_filetype = wp_check_filetype( basename( $file_path ), null );
		$attachment = array(
			// 'guid'           => $image_url,
			'post_mime_type' => $wp_filetype['type'],
			'post_title'     => preg_replace( '/\.[^.]+$/', '', basename( $file_path ) ),
			'post_content'   => '',
			'post_status'    => 'inherit'
		);

		$attach_id = wp_insert_attachment( $attachment, $file_path, 0  );
		require_once( ABSPATH . 'wp-admin/includes/image.php' );
		$attach_data = wp_generate_attachment_metadata( $attach_id, $file_path );
		wp_update_attachment_metadata( $attach_id, $attach_data );

		return $attach_id;
	}

	public function ajax_request()
	{
		$action = isset($_REQUEST['sub_action']) ? $_REQUEST['sub_action'] : 'none';

		$__ = array( 'add_campaign', 'remove_campaign', 'export_settings', 'import_settings' );

		if( in_array($action, $__) ){
			$params = isset($_REQUEST['params']) ? $_REQUEST['params'] : array();

			if( $action == 'import_settings' ){
				$fullsizepath = get_attached_file( $params['upload_id'] );

				WP_Filesystem();
				$upload_dir = wp_upload_dir();

				$backup_dirname = $upload_dir['basedir'] . '/' . WooZonePNF()->alias;
				if ( file_exists( $backup_dirname ) ) {
					$this->deleteDir( $backup_dirname );
				}

				if ( ! file_exists( $backup_dirname ) ) {
				    wp_mkdir_p( $backup_dirname );
				    wp_mkdir_p( $backup_dirname . '/attachments' );
				}

				$unzipfile = unzip_file( $fullsizepath, $backup_dirname );
				if( $unzipfile === true ){
					$export_file = WooZonePNF()->wp_filesystem->get_contents( $backup_dirname . '/export.json' );
					if( trim($export_file ) != "" ){
						$export_settings = json_decode( $export_file, true );

						$template_id = isset($params['template_id']) ? $params['template_id'] : '';

						// step 1 the template
						$template = isset($export_settings['template']) ? $export_settings['template'] : array();
						if( count($template) > 0 ){
							$_template = $template;
							$template = array();
							foreach ($_template as $key => $value) {
								if( in_array( $key, array_keys( $export_settings['files'] ) ) ){
									$value = $this->rebuild_attachament( $backup_dirname . '/' . $export_settings['files'][$key] );
								}
								$template[$key] = $value;
							}

							update_option( WooZonePNF()->alias . "_Template_Settings_" . $template_id, $template);
						}

						// step 2 the products
						$products = isset($export_settings['products']) ? $export_settings['products'] : array();
						if( count($products) > 0 ){
							update_option( WooZonePNF()->alias . "_" . $template_id . "_products", $products);
						}

						$settings = isset($export_settings['settings']) ? $export_settings['settings'] : array();
						if( count($settings) > 0 ){
							update_option( WooZonePNF()->alias . '_Plugin_Settings_' . $template_id, $settings);
						}

						die( json_encode( array(
							'status' => 'valid'
						) ));
					}
				}
			}

			if( $action == 'export_settings' ){

				$params['id'] = $_REQUEST['id'];
				$params['setup'] = $_REQUEST['setup'];
				$params['products'] = $_REQUEST['products'];
				$params['template'] = $_REQUEST['template'];

				$export = array();
				$attachments = array();
				$error = "";        // error holder
				$export['id'] = 'aa';

				$option = get_option( WooZonePNF()->alias . '_Plugin_Settings_' . $params['id'], true );
				if( $option && count($option) > 0 ){
					$export['settings'] = $option;
				}

				die( var_dump( "<pre>", $export  , "</pre>" ) . PHP_EOL .  __FILE__ . ":" . __LINE__  );

				$upload_dir = wp_upload_dir();
				$backup_dirname = $upload_dir['basedir'] . '/' . WooZonePNF()->alias;
				if ( ! file_exists( $backup_dirname ) ) {
				    wp_mkdir_p( $backup_dirname );
				    wp_mkdir_p( $backup_dirname . '/attachments' );
				}

				$attachments_files = array();
				if( count($attachments) > 0 ){
					foreach ($attachments as $key => $files) {
						if( count($files) > 0 ){
							foreach ($files as $key_file => $value_file) {
								$fullsizepath = get_attached_file( $value_file );

								$file_binary = WooZonePNF()->wp_filesystem->get_contents( $fullsizepath );
								$file_name = basename( $fullsizepath );

								WooZonePNF()->wp_filesystem->put_contents( $backup_dirname . '/attachments/' . $file_name, $file_binary );

								$attachments_files[$key_file] = 'attachments/' . $file_name;
							}
						}
					}
				}
				$export['files'] = $attachments_files;


				$input = WooZonePNF()->wp_filesystem->put_contents( $backup_dirname . '/export.json', json_encode( $export ) );
				if( $input === true ){

				    $files_to_zip = array(
				    	'export.json'
				    );
					$files_to_zip = $files_to_zip + $attachments_files;

				    $archive_name = $params['id'] . ".zip";
				    $result = $this->create_zip( $files_to_zip, $archive_name, true, $backup_dirname . '/' );

				    header('Content-Transfer-Encoding: binary'); //Transfert en binaire (fichier).
				    header('Content-Disposition: attachment; filename="' . ( $params['id'] ) . '.zip"'); //Nom du fichier.
				    header('Content-Length: ' . filesize($archive_name) ); //Taille du fichier.
				    readfile($archive_name);

				    $output_string = ob_get_contents();
				    ob_end_clean();
				    echo $output_string;
				    die;

				}else{
					$error = "Unable to save the file export tile";
				}

				echo $error;
				die;
			}

			if( $action == 'add_campaign' ){

				$campaigns = array();
				$options = get_option( $this->alias . "_campaigns", true );

				if( $this->has_campaigns($options) ){

					if( isset($options[ sanitize_title($params['name']) ]) ){
						die( json_encode( array(
							'status' => 'invalid',
							'msg' => 'Campaign with name: ' . $params['name'] . ' already exists!'
						) ));
					}else{
						$campaigns = $options;
						$campaigns[ sanitize_title($params['name']) ] = $params['name'];
					}
				}else{
					$campaigns[ sanitize_title($params['name']) ] = $params['name'];
				}

				update_option( $this->alias . "_campaigns", $campaigns );

				die( json_encode( array(
					'status' => 'valid',
					'redirect_url' => admin_url( 'admin.php?page=WooZonePNF&WooZonePNF_action=config&campaign_id=' . sanitize_title($params['name']) )
				) ));
			}

			if( $action == 'remove_campaign' ){
				$options = get_option( $this->alias . "_campaigns", true );
				if( $options ){
					if( isset($options[$params['id']]) ){
						unset( $options[$params['id']] );

						update_option( $this->alias . "_campaigns", $options );
					}
				}

				// to do delete of all data ... here

				die( json_encode( array(
					'status' => 'valid'
				) ));
			}
		}

		die("invalid action!");
	}

	public function get_total_search()
	{
		$totals = $this->db->get_row( "
			SELECT count(id) as total
			FROM " . ( $this->db->prefix . 'WooZonePNF_stats' ) . "
			WHERE 1=1
				AND action = 'new_search'
		");

		return $totals->total;
	}

	public function get_total_clicks()
	{
		$totals = $this->db->get_row( "
			SELECT count(id) as total
			FROM " . ( $this->db->prefix . 'WooZonePNF_stats' ) . "
			WHERE 1=1
				AND action = 'click'
		");

		return $totals->total;
	}

	public function best_keywords( $limit=5 )
	{
		$totals = $this->db->get_results( "
			SELECT keyword, COUNT(keyword) as total
			FROM " . ( $this->db->prefix . 'WooZonePNF_stats' ) . "
			WHERE 1=1 AND action = 'new_search' group by keyword order by total desc limit " . ( $limit ) . "
		", ARRAY_A);

		return $totals;
	}

	public function get_campaign_hits( $campaign_id='' )
	{
		$hits = $this->db->get_results( "
			SELECT DATE(date) Date, COUNT(action) as nb, action
			FROM " . ( $this->db->prefix . 'WooZonePNF_stats' ) . "
			WHERE 1=1
			GROUP   BY  DATE(date), action
		", ARRAY_A);

		$base = array();
		if( $hits && count($hits) > 0 ){
			foreach ($hits as $row) {
				$base[$row['Date']] = array(
					'click' => 0,
					'new_search' => 0
				);
			}

			foreach ($hits as $row) {
				if( !isset($base[$row['Date']][$row['action']]) || $base[$row['Date']][$row['action']] == 0 ){
					$base[$row['Date']][$row['action']] = $row['nb'];
				}
			}
		}

		return $base;
	}

	function create_date_range_array( $strDateFrom, $strDateTo )
	{
	    // takes two dates formatted as YYYY-MM-DD and creates an
	    // inclusive array of the dates between the from and to dates.

	    // could test validity of dates here but I'm already doing
	    // that in the main script

	    $aryRange=array();

	    $iDateFrom=mktime(1,0,0,substr($strDateFrom,5,2),     substr($strDateFrom,8,2),substr($strDateFrom,0,4));
	    $iDateTo=mktime(1,0,0,substr($strDateTo,5,2),     substr($strDateTo,8,2),substr($strDateTo,0,4));

	    if ($iDateTo>=$iDateFrom)
	    {
	        array_push($aryRange,date('Y-m-d',$iDateFrom)); // first entry
	        while ($iDateFrom<$iDateTo)
	        {
	            $iDateFrom+=86400; // add 24 hours
	            array_push($aryRange,date('Y-m-d',$iDateFrom));
	        }
	    }
	    return $aryRange;
	}

	public function get_roles()
	{
		$roles = get_editable_roles();
		$base = array();

		if( $roles && count(get_editable_roles()) > 0 ){
			foreach ($roles as $key => $value) {
				$base[$key] = $value['name'];
			}
		}

		return $base;
	}

	public function get_all_campaigns()
	{
		$campaigns = get_option( 'WooZonePNF_campaigns', true );
		if( is_array($campaigns) && $campaigns && count($campaigns) > 0 ){
			return $campaigns;
		}
		return array();
	}

	public function export_subs()
	{
		$subs = array();
		$rows = $this->db->get_results(
			"
			SELECT *
			FROM " . ( $this->db->prefix ) . "WooZonePNF_subs
			WHERE 1=1 AND campaign = '" . ( $this->get_campaign_id()  ) . "'
			"
		, ARRAY_A);

		if( $rows && count($rows) > 0 ){
			foreach ($rows as $key => $value) {
				$subs[] = $value['name'] . ", " . $value['email'];
			}
		}

		return implode("\n", $subs);
	}

	public function notification_bar_frontend()
	{
		require_once WooZonePNF()->path( 'TEMPLATES_DIR', 'notification-bar.php' );
	}

	public function discount_price_field()
	{
		global $post_id;

		woocommerce_wp_text_input( array(
			'id' => '_WooZonePNF_old_price',
			'class' => 'wc_input_price short',
			'label' => esc_html__( 'Old sales price', 'WooZonePNF' ) . ' (' . get_woocommerce_currency_symbol() . ')',
			'value'       => get_post_meta( $post_id, '_WooZonePNF_old_price', true ),
			'description' => esc_html__( 'WooZonePNF save here the original sales price. Use it for backup.', 'WooZonePNF' ),
			)
		);
	}

	public function amazon_sites()
	{
		$sites = array();

        $sites['com'] = array(
			'label' => 'United States',
			'flag' 	=> WooZonePNF()->assetUrl('images/flags/US.gif'),
			'url' 	=> 'https://affiliate-program.amazon.com',
			'api_url' => 'https://ws-na.amazon-adsystem.com/widgets/q?callback=search_callback&TemplateId=PubStudio&ServiceVersion=20070822&MarketPlace=US&Operation=ItemSearch&InstanceId=1&dataType=jsonp&Keywords={Keywords}&SearchIndex={SearchIndex}&multipageStart={paged}&multipageCount={items_per_page}'
		);

		$sites['uk'] = array(
			'label' => 'United Kingdom',
			'marketplace' => 'GB',
			'flag' 	=> WooZonePNF()->assetUrl('images/flags/UK.gif'),
			'url' 	=> 'https://affiliate-program.amazon.co.uk',
			'api_url' => 'https://ws-eu.amazon-adsystem.com/widgets/q?callback=search_callback&Operation=GetResults&MarketPlace=GB&Keywords={Keywords}&SearchIndex={SearchIndex}&multipageStart={paged}&InstanceId=0&multipageCount={items_per_page}&TemplateId=MobileSearchResults&ServiceVersion=20070822'
		);

		$sites['de'] = array(
			'label' => 'Deutschland',
			'flag' 	=> WooZonePNF()->assetUrl('images/flags/DE.gif'),
			'url' 	=> 'https://partnernet.amazon.de',
			'api_url' => 'https://ws-eu.amazon-adsystem.com/widgets/q?Operation=GetResults&MarketPlace=DE&Keywords={Keywords}&SearchIndex={SearchIndex}&multipageStart={paged}&InstanceId=0&multipageCount={items_per_page}&TemplateId=MobileSearchResults&ServiceVersion=20070822'
		);

		$sites['fr'] = array(
			'label' => 'France',
			'flag' 	=> WooZonePNF()->assetUrl('images/flags/FR.gif'),
			'url' 	=> 'https://partenaires.amazon.fr',
			'api_url' => 'https://ws-eu.amazon-adsystem.com/widgets/q?Operation=GetResults&MarketPlace=FR&Keywords={Keywords}&SearchIndex={SearchIndex}&multipageStart={paged}&InstanceId=0&multipageCount={items_per_page}&TemplateId=MobileSearchResults&ServiceVersion=20070822'
		);

		$sites['jp'] = array(
			'label' => 'Japan',
			'flag' 	=> WooZonePNF()->assetUrl('images/flags/JP.gif'),
			'url' 	=> 'https://affiliate.amazon.co.jp',
			'api_url' => 'https://ws-fe.amazon-adsystem.com/widgets/q?Operation=GetResults&Keywords={Keywords}&SearchIndex={SearchIndex}&multipageStart={paged}&InstanceId=0&multipageCount={items_per_page}&TemplateId=MobileSearchResults&ServiceVersion=20070822&MarketPlace=JP'
		);

		$sites['ca'] = array(
			'label' => 'Canada',
			'flag' 	=> WooZonePNF()->assetUrl('images/flags/CA.gif'),
			'url' 	=> 'https://associates.amazon.ca',
			'api_url' => 'https://ws-na.amazon-adsystem.com/widgets/q?callback=search_callback&TemplateId=PubStudio&ServiceVersion=20070822&MarketPlace=CA&Operation=ItemSearch&InstanceId=1&dataType=jsonp&Keywords={Keywords}&SearchIndex={SearchIndex}&multipageStart={paged}&multipageCount={items_per_page}'
		);

		/*
		$sites['cn'] = array(
			'label' => 'China',
			'flag' 	=> WooZonePNF()->assetUrl('images/flags/CN.gif'),
			'url' 	=> 'https://associates.amazon.cn'
		);*/

		$sites['it'] = array(
			'label' => 'Italia',
			'flag' 	=> WooZonePNF()->assetUrl('images/flags/IT.gif'),
			'url' 	=> 'https://programma-affiliazione.amazon.it',
			'api_url' => 'https://ws-eu.amazon-adsystem.com/widgets/q?Operation=GetResults&MarketPlace=IT&Keywords={Keywords}&SearchIndex={SearchIndex}&multipageStart={paged}&InstanceId=0&multipageCount={items_per_page}&TemplateId=MobileSearchResults&ServiceVersion=20070822'
		);

		$sites['es'] = array(
			'label' => 'España',
			'flag' 	=> WooZonePNF()->assetUrl('images/flags/ES.gif'),
			'url' 	=> 'https://afiliados.amazon.es',
			'api_url' => 'https://ws-eu.amazon-adsystem.com/widgets/q?Operation=GetResults&MarketPlace=ES&Keywords={Keywords}&SearchIndex={SearchIndex}&multipageStart={paged}&InstanceId=0&multipageCount={items_per_page}&TemplateId=MobileSearchResults&ServiceVersion=20070822'
		);

		$sites['in'] = array(
			'label' => 'India',
			'flag' 	=> WooZonePNF()->assetUrl('images/flags/IN.gif'),
			'url' 	=> 'https://affiliate-program.amazon.in',
			'api_url' => 'https://ws-eu.amazon-adsystem.com/widgets/q?Operation=GetResults&MarketPlace=IN&Keywords={Keywords}&SearchIndex={SearchIndex}&multipageStart={paged}&InstanceId=0&multipageCount={items_per_page}&TemplateId=MobileSearchResults&ServiceVersion=20070822'
		);

		/*

		$sites['br'] = array(
			'label' => 'Brazil',
			'flag' 	=> WooZonePNF()->assetUrl('images/flags/BR.gif'),
			'url' 	=> 'https://associados.amazon.com.br',
			'api_url' => 'https://ws-eu.amazon-adsystem.com/widgets/q?Operation=GetResults&MarketPlace=BR&Keywords={Keywords}&SearchIndex={SearchIndex}&multipageStart={paged}&InstanceId=0&multipageCount={items_per_page}&TemplateId=MobileSearchResults&ServiceVersion=20070822'
		);


		$sites['mx'] = array(
			'label' => 'Mexico',
			'flag' 	=> WooZonePNF()->assetUrl('images/flags/MX.jpg'),
			'url' 	=> 'https://afiliados.amazon.com.mx'
		);
		*/

		return $sites;
	}

	public function amazon_categories()
	{
		if( count($this->amz_cates) == 0 ){
			$file = $this->path( 'ASSETS_DIR', 'locales.json' );
			if( $this->wp_filesystem->get_contents( $file ) == false ) {
				$this->amz_cates = json_decode( file_get_contents( $file ), true);
			} else {
				$this->amz_cates = json_decode( $this->wp_filesystem->get_contents( $file ), true);
			}
		}

		return $this->amz_cates;
	}
}

/**
 * Main WooZonePNF manager.
 * @var WooZonePNF $WooZonePNF - instance of composer management.
 * @since 1.0
 */
global $WooZonePNF;
$WooZonePNF = new WooZonePNF();
